# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/data/v1/data.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_catalog_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2
from k8s.io.api.core.v1 import generated_pb2 as k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9github.com/metaprov/modelaapi/services/data/v1/data.proto\x12.github.com.metaprov.modelaapi.services.data.v1\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\x1aIgithub.com/metaprov/modelaapi/pkg/apis/inference/v1alpha1/generated.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1aGgithub.com/metaprov/modelaapi/pkg/apis/catalog/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\x1a\"k8s.io/api/core/v1/generated.proto\"\xfd\x03\n\x11\x44sReadFileRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12U\n\nconnection\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x05 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12]\n\x06secret\x18\x06 \x03(\x0b\x32M.github.com.metaprov.modelaapi.services.data.v1.DsReadFileRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x83\x04\n\x14\x44sReadFeatureRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\x06\x62ucket\x18\x04 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x05 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12`\n\x06secret\x18\x06 \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.data.v1.DsReadFeatureRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xcf\x04\n\x12\x44sWriteFileRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x07\x63ontent\x18\x03 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12T\n\x06\x62ucket\x18\x05 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x06 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12^\n\x06secret\x18\x07 \x03(\x0b\x32N.github.com.metaprov.modelaapi.services.data.v1.DsWriteFileRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xd0\x02\n\x12\x44sReadAudioRequest\x12T\n\x06\x62ucket\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12^\n\x06secret\x18\x03 \x03(\x0b\x32N.github.com.metaprov.modelaapi.services.data.v1.DsReadAudioRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x89\x04\n\x17\x44sReadTextCorpusRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\x06\x62ucket\x18\x03 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x63\n\x06secret\x18\x05 \x03(\x0b\x32S.github.com.metaprov.modelaapi.services.data.v1.DsReadTextCorpusRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xd8\x04\n\x17\x44sReadFromStoreResponse\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12M\n\x06result\x18\x03 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12T\n\x06\x62ucket\x18\x04 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x05 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x63\n\x06secret\x18\x06 \x03(\x0b\x32S.github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"p\n\x18\x44sRunDataPipelineRequest\x12T\n\x08pipeline\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\"j\n\x19\x44sRunDataPipelineResponse\x12M\n\x06result\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"\xd1\x08\n\x12\x44sRunRecipeRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12T\n\x06\x62ucket\x18\x05 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\\\n\x11storageConnection\x18\x06 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12l\n\rstorageSecret\x18\x07 \x03(\x0b\x32U.github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeRequest.StorageSecretEntry\x12W\n\x0c\x64\x62\x43onnection\x18\x08 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x62\n\x08\x64\x62Secret\x18\t \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeRequest.DbSecretEntry\x12L\n\x06recipe\x18\n \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\x12R\n\treciperun\x18\x0b \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\x1a\x34\n\x12StorageSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a/\n\rDbSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"c\n\x13\x44sRunRecipeResponse\x12L\n\x06result\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\"\x9b\x08\n\x1c\x44sCreateRecipeProfileRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12T\n\x06\x62ucket\x18\x05 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\\\n\x11storageConnection\x18\x06 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12v\n\rstorageSecret\x18\x07 \x03(\x0b\x32_.github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileRequest.StorageSecretEntry\x12W\n\x0c\x64\x62\x43onnection\x18\x08 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12l\n\x08\x64\x62Secret\x18\t \x03(\x0b\x32Z.github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileRequest.DbSecretEntry\x12L\n\x06recipe\x18\n \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\x1a\x34\n\x12StorageSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a/\n\rDbSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"l\n\x1d\x44sCreateRecipeProfileResponse\x12K\n\x06result\x18\x01 \x01(\x0b\x32;.github.com.metaprov.modelaapi.services.common.v1.TableView\"\x14\n\x12\x44\x61taSourceResponse\"\x11\n\x0f\x44\x61tasetResponse\"\xdf\x07\n\x1d\x44sCreateDatasetProfileRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12T\n\x06\x62ucket\x18\x05 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\\\n\x11storageConnection\x18\x06 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12w\n\rstorageSecret\x18\x07 \x03(\x0b\x32`.github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileRequest.StorageSecretEntry\x12W\n\x0c\x64\x62\x43onnection\x18\x08 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12m\n\x08\x64\x62Secret\x18\t \x03(\x0b\x32[.github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileRequest.DbSecretEntry\x12\r\n\x05group\x18\n \x01(\x08\x1a\x34\n\x12StorageSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a/\n\rDbSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x80\x01\n\x1e\x44sCreateDatasetProfileResponse\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12Q\n\x07profile\x18\x02 \x01(\x0b\x32@.github.com.metaprov.modelaapi.services.common.v1.DatasetProfile\"\xce\x08\n\x1b\x44sCreateModelProfileRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12N\n\x05study\x18\x05 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12N\n\x05model\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12U\n\nconnection\x18\x08 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\t \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12g\n\x06secret\x18\n \x03(\x0b\x32W.github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileRequest.SecretEntry\x12W\n\x0c\x64\x62\x43onnection\x18\x0b \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12k\n\x08\x64\x62Secret\x18\x0c \x03(\x0b\x32Y.github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileRequest.DbSecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a/\n\rDbSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"+\n\x1c\x44sCreateModelProfileResponse\x12\x0b\n\x03uri\x18\x01 \x01(\t\"\xde\x08\n\x1a\x44sMergeForecastFileRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12N\n\x05study\x18\x05 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12N\n\x05model\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12U\n\nconnection\x18\x08 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\t \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x66\n\x06secret\x18\n \x03(\x0b\x32V.github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileRequest.SecretEntry\x12\x11\n\tforecasts\x18\x0b \x03(\t\x12W\n\x0c\x64\x62\x43onnection\x18\x0c \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12j\n\x08\x64\x62Secret\x18\r \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileRequest.DbSecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a/\n\rDbSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"*\n\x1b\x44sMergeForecastFileResponse\x12\x0b\n\x03uri\x18\x01 \x01(\t\"\xcf\x08\n\x1b\x44sCreateStudyProfileRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x05study\x18\x04 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12N\n\x07\x64\x61taset\x18\x05 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\nconnection\x18\x06 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x07 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12O\n\x06models\x18\x08 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12g\n\x06secret\x18\t \x03(\x0b\x32W.github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileRequest.SecretEntry\x12W\n\x0c\x64\x62\x43onnection\x18\n \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12k\n\x08\x64\x62Secret\x18\x0b \x03(\x0b\x32Y.github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileRequest.DbSecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a/\n\rDbSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"+\n\x1c\x44sCreateStudyProfileResponse\x12\x0b\n\x03uri\x18\x01 \x01(\t\"\xd0\x11\n\x13RunTestSuiteRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12N\n\x05study\x18\x05 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12N\n\x05model\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12U\n\nconnection\x18\x07 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x08 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12_\n\x06secret\x18\n \x03(\x0b\x32O.github.com.metaprov.modelaapi.services.data.v1.RunTestSuiteRequest.SecretEntry\x12Q\n\x05suite\x18\x0b \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.TestSuite\x12S\n\nsutDataset\x18\x0c \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetH\x00\x12S\n\x08sutStudy\x18\r \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.StudyH\x00\x12S\n\x08sutModel\x18\x0e \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelH\x00\x12Q\n\tsutRecipe\x18\x0f \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeH\x00\x12^\n\x0csutHistogram\x18\x10 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogramH\x00\x12\\\n\x0csutPredictor\x18\x11 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.PredictorH\x00\x12S\n\nrefDataset\x18\x14 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetH\x01\x12S\n\x08refStudy\x18\x15 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.StudyH\x01\x12S\n\x08refModel\x18\x16 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelH\x01\x12Q\n\trefRecipe\x18\x17 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeH\x01\x12^\n\x0crefHistogram\x18\x18 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogramH\x01\x12\\\n\x0crefPredictor\x18\x19 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.PredictorH\x01\x12\r\n\x05group\x18\x1a \x01(\x08\x12W\n\x0c\x64\x62\x43onnection\x18\x1b \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x63\n\x08\x64\x62Secret\x18\x1c \x03(\x0b\x32Q.github.com.metaprov.modelaapi.services.data.v1.RunTestSuiteRequest.DbSecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a/\n\rDbSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x42\x0b\n\tsut_oneofB\t\n\x07sut_ref\"p\n\x14RunTestSuiteResponse\x12X\n\x06result\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.TestSuiteResult\"\xe3\x06\n\x18\x44sGenerateDatasetRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12U\n\nconnection\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x05 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x64\n\x06secret\x18\x06 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetRequest.SecretEntry\x12\x0c\n\x04rows\x18\x07 \x01(\x05\x12W\n\x0c\x64\x62\x43onnection\x18\x08 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12h\n\x08\x64\x62Secret\x18\t \x03(\x0b\x32V.github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetRequest.DbSecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a/\n\rDbSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"(\n\x19\x44sGenerateDatasetResponse\x12\x0b\n\x03key\x18\x01 \x01(\t\"\xaa\t\n\x15\x44sSplitDatasetRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\x06\x62ucket\x18\x03 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12T\n\ndatasource\x18\x04 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x05 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12N\n\x05study\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12U\n\nconnection\x18\x07 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x61\n\x06secret\x18\x08 \x03(\x0b\x32Q.github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetRequest.SecretEntry\x12V\n\x0ftrainingDataset\x18\t \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\x0etestingDataset\x18\n \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12\r\n\x05group\x18\x0b \x01(\x08\x12W\n\x0c\x64\x62\x43onnection\x18\x0c \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x65\n\x08\x64\x62Secret\x18\r \x03(\x0b\x32S.github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetRequest.DbSecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a/\n\rDbSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xa8\x01\n\x16\x44sSplitDatasetResponse\x12\x10\n\x08training\x18\x01 \x01(\x05\x12\x0f\n\x07testing\x18\x02 \x01(\x05\x12\x12\n\nvalidation\x18\x03 \x01(\x05\x12\x15\n\rtraining_hash\x18\x04 \x01(\t\x12\x14\n\x0ctesting_hash\x18\x05 \x01(\t\x12\x17\n\x0fvalidation_hash\x18\x06 \x01(\t\x12\x11\n\tindexFile\x18\x07 \x01(\t\"\xc8\x05\n\x1c\x44sSplitDatasetToRungsRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\x06\x62ucket\x18\x03 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12T\n\ndatasource\x18\x04 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x05 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\nconnection\x18\x06 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12h\n\x06secret\x18\x07 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsRequest.SecretEntry\x12\r\n\x05rungs\x18\x08 \x01(\x05\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x1f\n\x1d\x44sSplitDatasetToRungsResponse\"\xa4\x07\n\x12\x44sTransformRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\x06\x62ucket\x18\x03 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12T\n\ndatasource\x18\x04 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x05 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12N\n\x05study\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12U\n\nconnection\x18\x07 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12^\n\x06secret\x18\x08 \x03(\x0b\x32N.github.com.metaprov.modelaapi.services.data.v1.DsTransformRequest.SecretEntry\x12V\n\x0ftrainingDataset\x18\t \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\x0etestingDataset\x18\n \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"[\n\x13\x44sTransformResponse\x12\x15\n\rtraining_hash\x18\x04 \x01(\t\x12\x14\n\x0ctesting_hash\x18\x05 \x01(\t\x12\x17\n\x0fvalidation_hash\x18\x06 \x01(\t\"\xd9\x07\n\x1c\x44sCreateColumnProfileRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12T\n\x06\x62ucket\x18\x05 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x06 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12h\n\x06secret\x18\x07 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileRequest.SecretEntry\x12\x12\n\ncolumnType\x18\x08 \x01(\t\x12\x12\n\ncolumnName\x18\t \x01(\t\x12W\n\x0c\x64\x62\x43onnection\x18\n \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12l\n\x08\x64\x62Secret\x18\x0b \x03(\x0b\x32Z.github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileRequest.DbSecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a/\n\rDbSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"s\n\x1d\x44sCreateColumnProfileResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x44\n\x04plot\x18\x02 \x01(\x0b\x32\x36.github.com.metaprov.modelaapi.services.common.v1.Plot\"\x9c\x07\n\x15GroupByDatasetRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\nconnection\x18\x05 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x06 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x61\n\x06secret\x18\x07 \x03(\x0b\x32Q.github.com.metaprov.modelaapi.services.data.v1.GroupByDatasetRequest.SecretEntry\x12W\n\x0c\x64\x62\x43onnection\x18\x08 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x65\n\x08\x64\x62Secret\x18\t \x03(\x0b\x32S.github.com.metaprov.modelaapi.services.data.v1.GroupByDatasetRequest.DbSecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a/\n\rDbSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"%\n\x16GroupByDatasetResponse\x12\x0b\n\x03uri\x18\x01 \x01(\t\"\x80\x04\n\x14\x44sInferSchemaRequest\x12T\n\x06\x62ucket\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12T\n\x08location\x18\x02 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12U\n\nconnection\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12`\n\x06secret\x18\x05 \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"j\n\x15\x44sInferSchemaResponse\x12Q\n\x07profile\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.services.common.v1.DatasetProfile\"\xf9\x05\n\x15\x44sGetTableViewRequest\x12T\n\x06\x62ucket\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12Z\n\x08\x66latfile\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FlatFileFormatSpec\x12T\n\x08location\x18\x03 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12U\n\nconnection\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x61\n\x06secret\x18\x05 \x03(\x0b\x32Q.github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewRequest.SecretEntry\x12W\n\x0c\x64\x62\x43onnection\x18\x06 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x65\n\x08\x64\x62Secret\x18\x07 \x03(\x0b\x32S.github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewRequest.DbSecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a/\n\rDbSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"h\n\x16\x44sGetTableViewResponse\x12N\n\ttableview\x18\x01 \x01(\x0b\x32;.github.com.metaprov.modelaapi.services.common.v1.TableView\"\xb2\x07\n\x18\x43reateModelReportRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x05study\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12T\n\ndatasource\x18\x05 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x05model\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12U\n\nconnection\x18\x07 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x64\n\x06secret\x18\x08 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.data.v1.CreateModelReportRequest.SecretEntry\x12T\n\x06\x62ucket\x18\t \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12P\n\x06report\x18\n \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\x12\r\n\x05group\x18\x0b \x01(\x08\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xb2\t\n\x1b\x43reateForecastReportRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x05study\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12T\n\ndatasource\x18\x05 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12Q\n\x08\x66orecast\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12U\n\nconnection\x18\x07 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12g\n\x06secret\x18\x08 \x03(\x0b\x32W.github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest.SecretEntry\x12T\n\x06\x62ucket\x18\t \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12P\n\x06report\x18\n \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\x12\r\n\x05group\x18\x0b \x01(\x08\x12W\n\x0c\x64\x62\x43onnection\x18\x0c \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12k\n\x08\x64\x62Secret\x18\r \x03(\x0b\x32Y.github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest.DbSecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a/\n\rDbSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xd7\x06\n\x1a\x43reateSummaryReportRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12U\n\nconnection\x18\x03 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x66\n\x06secret\x18\x04 \x03(\x0b\x32V.github.com.metaprov.modelaapi.services.data.v1.CreateSummaryReportRequest.SecretEntry\x12T\n\x06\x62ucket\x18\x05 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12P\n\x06report\x18\x06 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\x12W\n\x0c\x64\x62\x43onnection\x18\x07 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12j\n\x08\x64\x62Secret\x18\x08 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.data.v1.CreateSummaryReportRequest.DbSecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a/\n\rDbSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"#\n\x14\x43reateReportResponse\x12\x0b\n\x03pdf\x18\x01 \x01(\x0c\"\x8c\x08\n\x1a\x43reateDatasetReportRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\nconnection\x18\x05 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x06 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x66\n\x06secret\x18\x07 \x03(\x0b\x32V.github.com.metaprov.modelaapi.services.data.v1.CreateDatasetReportRequest.SecretEntry\x12P\n\x06report\x18\x08 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\x12\r\n\x05group\x18\t \x01(\x08\x12W\n\x0c\x64\x62\x43onnection\x18\n \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12j\n\x08\x64\x62Secret\x18\x0b \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.data.v1.CreateDatasetReportRequest.DbSecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a/\n\rDbSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x9c\t\n\x18\x43reateStudyReportRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x05study\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12T\n\ndatasource\x18\x05 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12S\n\x06models\x18\x06 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelList\x12T\n\x06\x62ucket\x18\x07 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x08 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x64\n\x06secret\x18\t \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest.SecretEntry\x12P\n\x06report\x18\n \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\x12W\n\x0c\x64\x62\x43onnection\x18\x0b \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12h\n\x08\x64\x62Secret\x18\x0c \x03(\x0b\x32V.github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest.DbSecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a/\n\rDbSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xc4\x04\n\x0f\x41skModelRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x05study\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12T\n\ndatasource\x18\x04 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x05 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12\x0e\n\x06\x62udget\x18\x06 \x01(\x05\x12\x11\n\tdefaultHP\x18\x07 \x01(\x08\x12\x11\n\talgorithm\x18\x08 \x01(\t\x12V\n\nalgorithms\x18\t \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Algorithm\"\xc6\x03\n\x1fGetTimeSeriesDatasetKeysRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x05study\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12T\n\ndatasource\x18\x04 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x05 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"0\n GetTimeSeriesDatasetKeysResponse\x12\x0c\n\x04keys\x18\x01 \x03(\t\"\xa4\x04\n\x17\x41skForecastModelRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x05study\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12T\n\ndatasource\x18\x04 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x05 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12\x0c\n\x04keys\x18\x06 \x03(\t\x12V\n\nalgorithms\x18\x07 \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Algorithm\"j\n\x18\x41skForecastModelResponse\x12N\n\x05model\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"\xe2\x04\n\x12\x41skEnsembleRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x05study\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12T\n\ndatasource\x18\x04 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x05 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12O\n\x06models\x18\x06 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12V\n\nalgorithms\x18\x07 \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Algorithm\"e\n\x13\x41skEnsembleResponse\x12N\n\x05model\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"\xb0\x04\n\x12\x41skBaselineRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x05study\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12T\n\ndatasource\x18\x04 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x05 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12\x10\n\x08\x61lgnames\x18\x06 \x03(\t\x12\x0b\n\x03\x61ll\x18\x07 \x01(\x08\x12V\n\nalgorithms\x18\x08 \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Algorithm\"e\n\x13\x41skBaselineResponse\x12N\n\x05model\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"\xb7\x04\n\x1a\x41skAllModelsForTaskRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x05study\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12T\n\ndatasource\x18\x04 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x05 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12\x0e\n\x06\x62udget\x18\x06 \x01(\x05\x12\x0c\n\x04task\x18\x07 \x01(\t\x12V\n\nalgorithms\x18\x08 \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Algorithm\"m\n\x1b\x41skAllModelsForTaskResponse\x12N\n\x05model\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"\x97\x04\n\x10TellModelRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x05study\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12T\n\ndatasource\x18\x04 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x05 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12N\n\x05model\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12\x0e\n\x06\x66\x61iled\x18\x07 \x01(\x08\"#\n\x11TellModelResponse\x12\x0e\n\x06pruned\x18\x01 \x01(\x08\"\x13\n\x11\x44sShutdownRequest\"\x14\n\x12\x44sShutdownResponse\"\xda\x02\n\x17\x44sTestConnectionRequest\x12U\n\nconnection\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x02 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x63\n\x06secret\x18\x03 \x03(\x0b\x32S.github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"7\n\x18\x44sTestConnectionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\xf7\x05\n\x13\x44sStudyEndedRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12N\n\x05study\x18\x05 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12U\n\nconnection\x18\x06 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x07 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12_\n\x06secret\x18\x08 \x03(\x0b\x32O.github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x16\n\x14\x44sStudyEndedResponse\"\xfd\x05\n\x16SaveOptimizerDBRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12N\n\x05study\x18\x05 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12U\n\nconnection\x18\x06 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x07 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x62\n\x06secret\x18\x08 \x03(\x0b\x32R.github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x19\n\x17SaveOptimizerDBResponse\"\x80\x02\n\x15\x44sGetDatabasesRequest\x12U\n\nconnection\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x61\n\x06secret\x18\x02 \x03(\x0b\x32Q.github.com.metaprov.modelaapi.services.data.v1.DsGetDatabasesRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"+\n\x16\x44sGetDatabasesResponse\x12\x11\n\tdatabases\x18\x01 \x03(\t\"\x90\x02\n\x12\x44sGetTablesRequest\x12U\n\nconnection\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12^\n\x06secret\x18\x02 \x03(\x0b\x32N.github.com.metaprov.modelaapi.services.data.v1.DsGetTablesRequest.SecretEntry\x12\x14\n\x0c\x64\x61tabaseName\x18\x03 \x01(\t\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"%\n\x13\x44sGetTablesResponse\x12\x0e\n\x06tables\x18\x01 \x03(\t\"\x9f\x02\n\x13\x44sExecuteSqlRequest\x12U\n\nconnection\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12_\n\x06secret\x18\x02 \x03(\x0b\x32O.github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlRequest.SecretEntry\x12\x14\n\x0c\x64\x61tabaseName\x18\x03 \x01(\t\x12\x0b\n\x03sql\x18\x04 \x01(\t\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"f\n\x14\x44sExecuteSqlResponse\x12N\n\ttableview\x18\x01 \x01(\x0b\x32;.github.com.metaprov.modelaapi.services.common.v1.TableView\"\xb9\x07\n\x11\x44sSnapshotRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12W\n\x0c\x64\x62\x63onnection\x18\x05 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x61\n\x08\x64\x62secret\x18\x06 \x03(\x0b\x32O.github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.DbsecretEntry\x12\\\n\x11storageconnection\x18\x07 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12k\n\rstoragesecret\x18\x08 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.StoragesecretEntry\x12T\n\x06\x62ucket\x18\t \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x0b\n\x03key\x18\n \x01(\t\x1a/\n\rDbsecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a\x34\n\x12StoragesecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x14\n\x12\x44sSnapshotResponse\"b\n\x10\x41skModelResponse\x12N\n\x05model\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"\x95\x08\n\x16GenTrainingDataRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12\\\n\x11storageConnection\x18\x03 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12[\n\rstorageBucket\x18\x04 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12p\n\rstorageSecret\x18\x05 \x03(\x0b\x32Y.github.com.metaprov.modelaapi.services.data.v1.GenTrainingDataRequest.StorageSecretEntry\x12W\n\x0c\x64\x62\x43onnection\x18\x06 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x66\n\x08\x64\x62Secret\x18\x07 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.data.v1.GenTrainingDataRequest.DbSecretEntry\x12S\n\x05model\x18\x08 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClass\x12N\n\x08\x65ntities\x18\t \x03(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\x12R\n\x06groups\x18\n \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureGroup\x1a\x34\n\x12StorageSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a/\n\rDbSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\'\n\x17GenTrainingDataResponse\x12\x0c\n\x04path\x18\x01 \x01(\t\"\xe8\x06\n\x16SyncOnlineStoreRequest\x12\\\n\x11storageConnection\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12[\n\rstorageBucket\x18\x02 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12p\n\rstorageSecret\x18\x03 \x03(\x0b\x32Y.github.com.metaprov.modelaapi.services.data.v1.SyncOnlineStoreRequest.StorageSecretEntry\x12W\n\x0c\x64\x62\x43onnection\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x66\n\x08\x64\x62Secret\x18\x05 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.data.v1.SyncOnlineStoreRequest.DbSecretEntry\x12S\n\x05model\x18\x06 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClass\x12N\n\x02\x66g\x18\x07 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureGroup\x12T\n\x08location\x18\x08 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x1a\x34\n\x12StorageSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a/\n\rDbSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x19\n\x17SyncOnlineStoreResponse\"\xfa\x06\n\x1cGenOnlineStoreDatasetRequest\x12\\\n\x11storageConnection\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12[\n\rstorageBucket\x18\x02 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12v\n\rstorageSecret\x18\x03 \x03(\x0b\x32_.github.com.metaprov.modelaapi.services.data.v1.GenOnlineStoreDatasetRequest.StorageSecretEntry\x12W\n\x0c\x64\x62\x43onnection\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12l\n\x08\x64\x62Secret\x18\x05 \x03(\x0b\x32Z.github.com.metaprov.modelaapi.services.data.v1.GenOnlineStoreDatasetRequest.DbSecretEntry\x12S\n\x05model\x18\x06 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClass\x12N\n\x02\x66g\x18\x07 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureGroup\x12T\n\x08location\x18\x08 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x1a\x34\n\x12StorageSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a/\n\rDbSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"u\n\x1dGenOnlineStoreDatasetResponse\x12T\n\x08location\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\"\x8d\x08\n\x13\x42\x61tchPredictRequest\x12\\\n\x11storageConnection\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12[\n\rstorageBucket\x18\x02 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12m\n\rstorageSecret\x18\x03 \x03(\x0b\x32V.github.com.metaprov.modelaapi.services.data.v1.BatchPredictRequest.StorageSecretEntry\x12W\n\x0c\x64\x62\x43onnection\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x63\n\x08\x64\x62Secret\x18\x05 \x03(\x0b\x32Q.github.com.metaprov.modelaapi.services.data.v1.BatchPredictRequest.DbSecretEntry\x12X\n\nmodelclass\x18\x06 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClass\x12N\n\x05model\x18\x07 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12N\n\x08\x65ntities\x18\x08 \x03(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\x12R\n\x06groups\x18\t \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureGroup\x12Y\n\nprediction\x18\n \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\x1a\x34\n\x12StorageSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a/\n\rDbSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"$\n\x14\x42\x61tchPredictResponse\x12\x0c\n\x04rows\x18\x01 \x01(\x05\"\xe2\x08\n\x12SaveDatasetRequest\x12\\\n\x11storageConnection\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12[\n\rstorageBucket\x18\x02 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12l\n\rstorageSecret\x18\x03 \x03(\x0b\x32U.github.com.metaprov.modelaapi.services.data.v1.SaveDatasetRequest.StorageSecretEntry\x12V\n\x0b\x64\x61taproduct\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12T\n\ndatasource\x18\x05 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12X\n\nmodelclass\x18\x06 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClass\x12^\n\rmodelclassrun\x18\x07 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClassRun\x12N\n\x07\x64\x61taset\x18\x08 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12G\n\x03lab\x18\t \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\x12W\n\x0c\x64\x62\x43onnection\x18\n \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x62\n\x08\x64\x62Secret\x18\x0b \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.data.v1.SaveDatasetRequest.DbSecretEntry\x1a\x34\n\x12StorageSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a/\n\rDbSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xfa\t\n\x10SaveModelRequest\x12\\\n\x11storageConnection\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12[\n\rstorageBucket\x18\x02 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12j\n\rstorageSecret\x18\x03 \x03(\x0b\x32S.github.com.metaprov.modelaapi.services.data.v1.SaveModelRequest.StorageSecretEntry\x12V\n\x0b\x64\x61taproduct\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12N\n\x05study\x18\x05 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12X\n\nmodelclass\x18\x06 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClass\x12^\n\rmodelclassrun\x18\x07 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClassRun\x12N\n\x05model\x18\x08 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12G\n\x03lab\x18\t \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\x12N\n\x08\x65ntities\x18\n \x03(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\x12R\n\x06groups\x18\x0b \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureGroup\x12W\n\x0c\x64\x62\x43onnection\x18\x0c \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12`\n\x08\x64\x62Secret\x18\r \x03(\x0b\x32N.github.com.metaprov.modelaapi.services.data.v1.SaveModelRequest.DbSecretEntry\x1a\x34\n\x12StorageSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a/\n\rDbSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xa9\x08\n\x15SavePredictionRequest\x12\\\n\x11storageConnection\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12[\n\rstorageBucket\x18\x02 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12o\n\rstorageSecret\x18\x03 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.data.v1.SavePredictionRequest.StorageSecretEntry\x12V\n\x0b\x64\x61taproduct\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12X\n\nmodelclass\x18\x05 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClass\x12W\n\tpredictor\x18\x06 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\x12Y\n\nprediction\x18\x07 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\x12W\n\x0bservingsite\x18\x08 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ServingSite\x12W\n\x0c\x64\x62\x43onnection\x18\t \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x65\n\x08\x64\x62Secret\x18\n \x03(\x0b\x32S.github.com.metaprov.modelaapi.services.data.v1.SavePredictionRequest.DbSecretEntry\x1a\x34\n\x12StorageSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a/\n\rDbSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"+\n\x19\x43reateMetricsStoreRequest\x12\x0e\n\x06tenant\x18\x01 \x01(\t\"\x1c\n\x1a\x43reateMetricsStoreResponse\"\x1c\n\x0cSaveResponse\x12\x0c\n\x04\x64\x62id\x18\x01 \x01(\x05\x32\xf7\x43\n\x0b\x44\x61taService\x12\x98\x01\n\x08ReadFile\x12\x41.github.com.metaprov.modelaapi.services.data.v1.DsReadFileRequest\x1aG.github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse\"\x00\x12\x9e\x01\n\x0bReadFeature\x12\x44.github.com.metaprov.modelaapi.services.data.v1.DsReadFeatureRequest\x1aG.github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse\"\x00\x12\x9a\x01\n\tReadAudio\x12\x42.github.com.metaprov.modelaapi.services.data.v1.DsReadAudioRequest\x1aG.github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse\"\x00\x12\xa8\x01\n\x0fRunDataPipeline\x12H.github.com.metaprov.modelaapi.services.data.v1.DsRunDataPipelineRequest\x1aI.github.com.metaprov.modelaapi.services.data.v1.DsRunDataPipelineResponse\"\x00\x12\x96\x01\n\tRunRecipe\x12\x42.github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeRequest\x1a\x43.github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeResponse\"\x00\x12\x9a\x01\n\tWriteFile\x12\x42.github.com.metaprov.modelaapi.services.data.v1.DsWriteFileRequest\x1aG.github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse\"\x00\x12\xa8\x01\n\x0fGenerateDataset\x12H.github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetRequest\x1aI.github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetResponse\"\x00\x12\x9f\x01\n\x0cSplitDataset\x12\x45.github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetRequest\x1a\x46.github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetResponse\"\x00\x12\x96\x01\n\tTransform\x12\x42.github.com.metaprov.modelaapi.services.data.v1.DsTransformRequest\x1a\x43.github.com.metaprov.modelaapi.services.data.v1.DsTransformResponse\"\x00\x12\xb4\x01\n\x13\x43reateColumnProfile\x12L.github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileRequest\x1aM.github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileResponse\"\x00\x12\x9c\x01\n\x0bInferSchema\x12\x44.github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaRequest\x1a\x45.github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaResponse\"\x00\x12\x9f\x01\n\x0cGetTableView\x12\x45.github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewRequest\x1a\x46.github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewResponse\"\x00\x12\xb4\x01\n\x13SplitDatasetToRungs\x12L.github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsRequest\x1aM.github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsResponse\"\x00\x12\xb7\x01\n\x14\x43reateDatasetProfile\x12M.github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileRequest\x1aN.github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileResponse\"\x00\x12\xb1\x01\n\x12\x43reateModelProfile\x12K.github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileRequest\x1aL.github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileResponse\"\x00\x12\xb1\x01\n\x12\x43reateStudyProfile\x12K.github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileRequest\x1aL.github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileResponse\"\x00\x12\xb4\x01\n\x13\x43reateRecipeProfile\x12L.github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileRequest\x1aM.github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileResponse\"\x00\x12\xa5\x01\n\x11\x43reateModelReport\x12H.github.com.metaprov.modelaapi.services.data.v1.CreateModelReportRequest\x1a\x44.github.com.metaprov.modelaapi.services.data.v1.CreateReportResponse\"\x00\x12\xa5\x01\n\x11\x43reateStudyReport\x12H.github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest\x1a\x44.github.com.metaprov.modelaapi.services.data.v1.CreateReportResponse\"\x00\x12\xa9\x01\n\x13\x43reateDatasetReport\x12J.github.com.metaprov.modelaapi.services.data.v1.CreateDatasetReportRequest\x1a\x44.github.com.metaprov.modelaapi.services.data.v1.CreateReportResponse\"\x00\x12\xab\x01\n\x14\x43reateForecastReport\x12K.github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest\x1a\x44.github.com.metaprov.modelaapi.services.data.v1.CreateReportResponse\"\x00\x12\xa9\x01\n\x13\x43reateSummaryReport\x12J.github.com.metaprov.modelaapi.services.data.v1.CreateSummaryReportRequest\x1a\x44.github.com.metaprov.modelaapi.services.data.v1.CreateReportResponse\"\x00\x12\x8c\x01\n\x05\x41skFE\x12?.github.com.metaprov.modelaapi.services.data.v1.AskModelRequest\x1a@.github.com.metaprov.modelaapi.services.data.v1.AskModelResponse\"\x00\x12\x98\x01\n\x0b\x41skBaseline\x12\x42.github.com.metaprov.modelaapi.services.data.v1.AskBaselineRequest\x1a\x43.github.com.metaprov.modelaapi.services.data.v1.AskBaselineResponse\"\x00\x12\x98\x01\n\x0b\x41skEnsemble\x12\x42.github.com.metaprov.modelaapi.services.data.v1.AskEnsembleRequest\x1a\x43.github.com.metaprov.modelaapi.services.data.v1.AskEnsembleResponse\"\x00\x12\xa7\x01\n\x10\x41skForecastModel\x12G.github.com.metaprov.modelaapi.services.data.v1.AskForecastModelRequest\x1aH.github.com.metaprov.modelaapi.services.data.v1.AskForecastModelResponse\"\x00\x12\x8f\x01\n\x08\x41skModel\x12?.github.com.metaprov.modelaapi.services.data.v1.AskModelRequest\x1a@.github.com.metaprov.modelaapi.services.data.v1.AskModelResponse\"\x00\x12\xb0\x01\n\x13\x41skAllModelsForTask\x12J.github.com.metaprov.modelaapi.services.data.v1.AskAllModelsForTaskRequest\x1aK.github.com.metaprov.modelaapi.services.data.v1.AskAllModelsForTaskResponse\"\x00\x12\x99\x01\n\x10TellPartialModel\x12@.github.com.metaprov.modelaapi.services.data.v1.TellModelRequest\x1a\x41.github.com.metaprov.modelaapi.services.data.v1.TellModelResponse\"\x00\x12\x92\x01\n\tTellModel\x12@.github.com.metaprov.modelaapi.services.data.v1.TellModelRequest\x1a\x41.github.com.metaprov.modelaapi.services.data.v1.TellModelResponse\"\x00\x12\xae\x01\n\x11MergeForecastFile\x12J.github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileRequest\x1aK.github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileResponse\"\x00\x12\xa7\x01\n\x10\x44sTestConnection\x12G.github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionRequest\x1aH.github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionResponse\"\x00\x12\x93\x01\n\x08ShutDown\x12\x41.github.com.metaprov.modelaapi.services.data.v1.DsShutdownRequest\x1a\x42.github.com.metaprov.modelaapi.services.data.v1.DsShutdownResponse\"\x00\x12\x99\x01\n\nStudyEnded\x12\x43.github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedRequest\x1a\x44.github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedResponse\"\x00\x12\xa4\x01\n\x0fSaveOptimizerDB\x12\x46.github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBRequest\x1aG.github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBResponse\"\x00\x12\x9f\x01\n\x0cGetDatabases\x12\x45.github.com.metaprov.modelaapi.services.data.v1.DsGetDatabasesRequest\x1a\x46.github.com.metaprov.modelaapi.services.data.v1.DsGetDatabasesResponse\"\x00\x12\x96\x01\n\tGetTables\x12\x42.github.com.metaprov.modelaapi.services.data.v1.DsGetTablesRequest\x1a\x43.github.com.metaprov.modelaapi.services.data.v1.DsGetTablesResponse\"\x00\x12\x99\x01\n\nExecuteSql\x12\x43.github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlRequest\x1a\x44.github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlResponse\"\x00\x12\x93\x01\n\x08Snapshot\x12\x41.github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest\x1a\x42.github.com.metaprov.modelaapi.services.data.v1.DsSnapshotResponse\"\x00\x12\x9e\x01\n\x0fUnitTestDataset\x12\x43.github.com.metaprov.modelaapi.services.data.v1.RunTestSuiteRequest\x1a\x44.github.com.metaprov.modelaapi.services.data.v1.RunTestSuiteResponse\"\x00\x12\x9c\x01\n\rUnitTestModel\x12\x43.github.com.metaprov.modelaapi.services.data.v1.RunTestSuiteRequest\x1a\x44.github.com.metaprov.modelaapi.services.data.v1.RunTestSuiteResponse\"\x00\x12\x9f\x01\n\x10UnitTestFeedback\x12\x43.github.com.metaprov.modelaapi.services.data.v1.RunTestSuiteRequest\x1a\x44.github.com.metaprov.modelaapi.services.data.v1.RunTestSuiteResponse\"\x00\x12\xa7\x01\n\x18UnitTestFeatureHistogram\x12\x43.github.com.metaprov.modelaapi.services.data.v1.RunTestSuiteRequest\x1a\x44.github.com.metaprov.modelaapi.services.data.v1.RunTestSuiteResponse\"\x00\x12\xa0\x01\n\x11UnitTestPredictor\x12\x43.github.com.metaprov.modelaapi.services.data.v1.RunTestSuiteRequest\x1a\x44.github.com.metaprov.modelaapi.services.data.v1.RunTestSuiteResponse\"\x00\x12\xa1\x01\n\x0eGroupByDataset\x12\x45.github.com.metaprov.modelaapi.services.data.v1.GroupByDatasetRequest\x1a\x46.github.com.metaprov.modelaapi.services.data.v1.GroupByDatasetResponse\"\x00\x12\xa4\x01\n\x0fSyncOnlineStore\x12\x46.github.com.metaprov.modelaapi.services.data.v1.SyncOnlineStoreRequest\x1aG.github.com.metaprov.modelaapi.services.data.v1.SyncOnlineStoreResponse\"\x00\x12\xa4\x01\n\x0fGenTrainingData\x12\x46.github.com.metaprov.modelaapi.services.data.v1.GenTrainingDataRequest\x1aG.github.com.metaprov.modelaapi.services.data.v1.GenTrainingDataResponse\"\x00\x12\xb6\x01\n\x15GenOnlineStoreDataset\x12L.github.com.metaprov.modelaapi.services.data.v1.GenOnlineStoreDatasetRequest\x1aM.github.com.metaprov.modelaapi.services.data.v1.GenOnlineStoreDatasetResponse\"\x00\x12\x9b\x01\n\x0c\x42\x61tchPredict\x12\x43.github.com.metaprov.modelaapi.services.data.v1.BatchPredictRequest\x1a\x44.github.com.metaprov.modelaapi.services.data.v1.BatchPredictResponse\"\x00\x12\x91\x01\n\x0bSaveDataSet\x12\x42.github.com.metaprov.modelaapi.services.data.v1.SaveDatasetRequest\x1a<.github.com.metaprov.modelaapi.services.data.v1.SaveResponse\"\x00\x12\x8d\x01\n\tSaveModel\x12@.github.com.metaprov.modelaapi.services.data.v1.SaveModelRequest\x1a<.github.com.metaprov.modelaapi.services.data.v1.SaveResponse\"\x00\x12\x97\x01\n\x0eSavePrediction\x12\x45.github.com.metaprov.modelaapi.services.data.v1.SavePredictionRequest\x1a<.github.com.metaprov.modelaapi.services.data.v1.SaveResponse\"\x00\x12\xad\x01\n\x12\x43reateMetricsStore\x12I.github.com.metaprov.modelaapi.services.data.v1.CreateMetricsStoreRequest\x1aJ.github.com.metaprov.modelaapi.services.data.v1.CreateMetricsStoreResponse\"\x00\x42\x30Z.github.com/metaprov/modelaapi/services/data/v1b\x06proto3')



_DSREADFILEREQUEST = DESCRIPTOR.message_types_by_name['DsReadFileRequest']
_DSREADFILEREQUEST_SECRETENTRY = _DSREADFILEREQUEST.nested_types_by_name['SecretEntry']
_DSREADFEATUREREQUEST = DESCRIPTOR.message_types_by_name['DsReadFeatureRequest']
_DSREADFEATUREREQUEST_SECRETENTRY = _DSREADFEATUREREQUEST.nested_types_by_name['SecretEntry']
_DSWRITEFILEREQUEST = DESCRIPTOR.message_types_by_name['DsWriteFileRequest']
_DSWRITEFILEREQUEST_SECRETENTRY = _DSWRITEFILEREQUEST.nested_types_by_name['SecretEntry']
_DSREADAUDIOREQUEST = DESCRIPTOR.message_types_by_name['DsReadAudioRequest']
_DSREADAUDIOREQUEST_SECRETENTRY = _DSREADAUDIOREQUEST.nested_types_by_name['SecretEntry']
_DSREADTEXTCORPUSREQUEST = DESCRIPTOR.message_types_by_name['DsReadTextCorpusRequest']
_DSREADTEXTCORPUSREQUEST_SECRETENTRY = _DSREADTEXTCORPUSREQUEST.nested_types_by_name['SecretEntry']
_DSREADFROMSTORERESPONSE = DESCRIPTOR.message_types_by_name['DsReadFromStoreResponse']
_DSREADFROMSTORERESPONSE_SECRETENTRY = _DSREADFROMSTORERESPONSE.nested_types_by_name['SecretEntry']
_DSRUNDATAPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['DsRunDataPipelineRequest']
_DSRUNDATAPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['DsRunDataPipelineResponse']
_DSRUNRECIPEREQUEST = DESCRIPTOR.message_types_by_name['DsRunRecipeRequest']
_DSRUNRECIPEREQUEST_STORAGESECRETENTRY = _DSRUNRECIPEREQUEST.nested_types_by_name['StorageSecretEntry']
_DSRUNRECIPEREQUEST_DBSECRETENTRY = _DSRUNRECIPEREQUEST.nested_types_by_name['DbSecretEntry']
_DSRUNRECIPERESPONSE = DESCRIPTOR.message_types_by_name['DsRunRecipeResponse']
_DSCREATERECIPEPROFILEREQUEST = DESCRIPTOR.message_types_by_name['DsCreateRecipeProfileRequest']
_DSCREATERECIPEPROFILEREQUEST_STORAGESECRETENTRY = _DSCREATERECIPEPROFILEREQUEST.nested_types_by_name['StorageSecretEntry']
_DSCREATERECIPEPROFILEREQUEST_DBSECRETENTRY = _DSCREATERECIPEPROFILEREQUEST.nested_types_by_name['DbSecretEntry']
_DSCREATERECIPEPROFILERESPONSE = DESCRIPTOR.message_types_by_name['DsCreateRecipeProfileResponse']
_DATASOURCERESPONSE = DESCRIPTOR.message_types_by_name['DataSourceResponse']
_DATASETRESPONSE = DESCRIPTOR.message_types_by_name['DatasetResponse']
_DSCREATEDATASETPROFILEREQUEST = DESCRIPTOR.message_types_by_name['DsCreateDatasetProfileRequest']
_DSCREATEDATASETPROFILEREQUEST_STORAGESECRETENTRY = _DSCREATEDATASETPROFILEREQUEST.nested_types_by_name['StorageSecretEntry']
_DSCREATEDATASETPROFILEREQUEST_DBSECRETENTRY = _DSCREATEDATASETPROFILEREQUEST.nested_types_by_name['DbSecretEntry']
_DSCREATEDATASETPROFILERESPONSE = DESCRIPTOR.message_types_by_name['DsCreateDatasetProfileResponse']
_DSCREATEMODELPROFILEREQUEST = DESCRIPTOR.message_types_by_name['DsCreateModelProfileRequest']
_DSCREATEMODELPROFILEREQUEST_SECRETENTRY = _DSCREATEMODELPROFILEREQUEST.nested_types_by_name['SecretEntry']
_DSCREATEMODELPROFILEREQUEST_DBSECRETENTRY = _DSCREATEMODELPROFILEREQUEST.nested_types_by_name['DbSecretEntry']
_DSCREATEMODELPROFILERESPONSE = DESCRIPTOR.message_types_by_name['DsCreateModelProfileResponse']
_DSMERGEFORECASTFILEREQUEST = DESCRIPTOR.message_types_by_name['DsMergeForecastFileRequest']
_DSMERGEFORECASTFILEREQUEST_SECRETENTRY = _DSMERGEFORECASTFILEREQUEST.nested_types_by_name['SecretEntry']
_DSMERGEFORECASTFILEREQUEST_DBSECRETENTRY = _DSMERGEFORECASTFILEREQUEST.nested_types_by_name['DbSecretEntry']
_DSMERGEFORECASTFILERESPONSE = DESCRIPTOR.message_types_by_name['DsMergeForecastFileResponse']
_DSCREATESTUDYPROFILEREQUEST = DESCRIPTOR.message_types_by_name['DsCreateStudyProfileRequest']
_DSCREATESTUDYPROFILEREQUEST_SECRETENTRY = _DSCREATESTUDYPROFILEREQUEST.nested_types_by_name['SecretEntry']
_DSCREATESTUDYPROFILEREQUEST_DBSECRETENTRY = _DSCREATESTUDYPROFILEREQUEST.nested_types_by_name['DbSecretEntry']
_DSCREATESTUDYPROFILERESPONSE = DESCRIPTOR.message_types_by_name['DsCreateStudyProfileResponse']
_RUNTESTSUITEREQUEST = DESCRIPTOR.message_types_by_name['RunTestSuiteRequest']
_RUNTESTSUITEREQUEST_SECRETENTRY = _RUNTESTSUITEREQUEST.nested_types_by_name['SecretEntry']
_RUNTESTSUITEREQUEST_DBSECRETENTRY = _RUNTESTSUITEREQUEST.nested_types_by_name['DbSecretEntry']
_RUNTESTSUITERESPONSE = DESCRIPTOR.message_types_by_name['RunTestSuiteResponse']
_DSGENERATEDATASETREQUEST = DESCRIPTOR.message_types_by_name['DsGenerateDatasetRequest']
_DSGENERATEDATASETREQUEST_SECRETENTRY = _DSGENERATEDATASETREQUEST.nested_types_by_name['SecretEntry']
_DSGENERATEDATASETREQUEST_DBSECRETENTRY = _DSGENERATEDATASETREQUEST.nested_types_by_name['DbSecretEntry']
_DSGENERATEDATASETRESPONSE = DESCRIPTOR.message_types_by_name['DsGenerateDatasetResponse']
_DSSPLITDATASETREQUEST = DESCRIPTOR.message_types_by_name['DsSplitDatasetRequest']
_DSSPLITDATASETREQUEST_SECRETENTRY = _DSSPLITDATASETREQUEST.nested_types_by_name['SecretEntry']
_DSSPLITDATASETREQUEST_DBSECRETENTRY = _DSSPLITDATASETREQUEST.nested_types_by_name['DbSecretEntry']
_DSSPLITDATASETRESPONSE = DESCRIPTOR.message_types_by_name['DsSplitDatasetResponse']
_DSSPLITDATASETTORUNGSREQUEST = DESCRIPTOR.message_types_by_name['DsSplitDatasetToRungsRequest']
_DSSPLITDATASETTORUNGSREQUEST_SECRETENTRY = _DSSPLITDATASETTORUNGSREQUEST.nested_types_by_name['SecretEntry']
_DSSPLITDATASETTORUNGSRESPONSE = DESCRIPTOR.message_types_by_name['DsSplitDatasetToRungsResponse']
_DSTRANSFORMREQUEST = DESCRIPTOR.message_types_by_name['DsTransformRequest']
_DSTRANSFORMREQUEST_SECRETENTRY = _DSTRANSFORMREQUEST.nested_types_by_name['SecretEntry']
_DSTRANSFORMRESPONSE = DESCRIPTOR.message_types_by_name['DsTransformResponse']
_DSCREATECOLUMNPROFILEREQUEST = DESCRIPTOR.message_types_by_name['DsCreateColumnProfileRequest']
_DSCREATECOLUMNPROFILEREQUEST_SECRETENTRY = _DSCREATECOLUMNPROFILEREQUEST.nested_types_by_name['SecretEntry']
_DSCREATECOLUMNPROFILEREQUEST_DBSECRETENTRY = _DSCREATECOLUMNPROFILEREQUEST.nested_types_by_name['DbSecretEntry']
_DSCREATECOLUMNPROFILERESPONSE = DESCRIPTOR.message_types_by_name['DsCreateColumnProfileResponse']
_GROUPBYDATASETREQUEST = DESCRIPTOR.message_types_by_name['GroupByDatasetRequest']
_GROUPBYDATASETREQUEST_SECRETENTRY = _GROUPBYDATASETREQUEST.nested_types_by_name['SecretEntry']
_GROUPBYDATASETREQUEST_DBSECRETENTRY = _GROUPBYDATASETREQUEST.nested_types_by_name['DbSecretEntry']
_GROUPBYDATASETRESPONSE = DESCRIPTOR.message_types_by_name['GroupByDatasetResponse']
_DSINFERSCHEMAREQUEST = DESCRIPTOR.message_types_by_name['DsInferSchemaRequest']
_DSINFERSCHEMAREQUEST_SECRETENTRY = _DSINFERSCHEMAREQUEST.nested_types_by_name['SecretEntry']
_DSINFERSCHEMARESPONSE = DESCRIPTOR.message_types_by_name['DsInferSchemaResponse']
_DSGETTABLEVIEWREQUEST = DESCRIPTOR.message_types_by_name['DsGetTableViewRequest']
_DSGETTABLEVIEWREQUEST_SECRETENTRY = _DSGETTABLEVIEWREQUEST.nested_types_by_name['SecretEntry']
_DSGETTABLEVIEWREQUEST_DBSECRETENTRY = _DSGETTABLEVIEWREQUEST.nested_types_by_name['DbSecretEntry']
_DSGETTABLEVIEWRESPONSE = DESCRIPTOR.message_types_by_name['DsGetTableViewResponse']
_CREATEMODELREPORTREQUEST = DESCRIPTOR.message_types_by_name['CreateModelReportRequest']
_CREATEMODELREPORTREQUEST_SECRETENTRY = _CREATEMODELREPORTREQUEST.nested_types_by_name['SecretEntry']
_CREATEFORECASTREPORTREQUEST = DESCRIPTOR.message_types_by_name['CreateForecastReportRequest']
_CREATEFORECASTREPORTREQUEST_SECRETENTRY = _CREATEFORECASTREPORTREQUEST.nested_types_by_name['SecretEntry']
_CREATEFORECASTREPORTREQUEST_DBSECRETENTRY = _CREATEFORECASTREPORTREQUEST.nested_types_by_name['DbSecretEntry']
_CREATESUMMARYREPORTREQUEST = DESCRIPTOR.message_types_by_name['CreateSummaryReportRequest']
_CREATESUMMARYREPORTREQUEST_SECRETENTRY = _CREATESUMMARYREPORTREQUEST.nested_types_by_name['SecretEntry']
_CREATESUMMARYREPORTREQUEST_DBSECRETENTRY = _CREATESUMMARYREPORTREQUEST.nested_types_by_name['DbSecretEntry']
_CREATEREPORTRESPONSE = DESCRIPTOR.message_types_by_name['CreateReportResponse']
_CREATEDATASETREPORTREQUEST = DESCRIPTOR.message_types_by_name['CreateDatasetReportRequest']
_CREATEDATASETREPORTREQUEST_SECRETENTRY = _CREATEDATASETREPORTREQUEST.nested_types_by_name['SecretEntry']
_CREATEDATASETREPORTREQUEST_DBSECRETENTRY = _CREATEDATASETREPORTREQUEST.nested_types_by_name['DbSecretEntry']
_CREATESTUDYREPORTREQUEST = DESCRIPTOR.message_types_by_name['CreateStudyReportRequest']
_CREATESTUDYREPORTREQUEST_SECRETENTRY = _CREATESTUDYREPORTREQUEST.nested_types_by_name['SecretEntry']
_CREATESTUDYREPORTREQUEST_DBSECRETENTRY = _CREATESTUDYREPORTREQUEST.nested_types_by_name['DbSecretEntry']
_ASKMODELREQUEST = DESCRIPTOR.message_types_by_name['AskModelRequest']
_GETTIMESERIESDATASETKEYSREQUEST = DESCRIPTOR.message_types_by_name['GetTimeSeriesDatasetKeysRequest']
_GETTIMESERIESDATASETKEYSRESPONSE = DESCRIPTOR.message_types_by_name['GetTimeSeriesDatasetKeysResponse']
_ASKFORECASTMODELREQUEST = DESCRIPTOR.message_types_by_name['AskForecastModelRequest']
_ASKFORECASTMODELRESPONSE = DESCRIPTOR.message_types_by_name['AskForecastModelResponse']
_ASKENSEMBLEREQUEST = DESCRIPTOR.message_types_by_name['AskEnsembleRequest']
_ASKENSEMBLERESPONSE = DESCRIPTOR.message_types_by_name['AskEnsembleResponse']
_ASKBASELINEREQUEST = DESCRIPTOR.message_types_by_name['AskBaselineRequest']
_ASKBASELINERESPONSE = DESCRIPTOR.message_types_by_name['AskBaselineResponse']
_ASKALLMODELSFORTASKREQUEST = DESCRIPTOR.message_types_by_name['AskAllModelsForTaskRequest']
_ASKALLMODELSFORTASKRESPONSE = DESCRIPTOR.message_types_by_name['AskAllModelsForTaskResponse']
_TELLMODELREQUEST = DESCRIPTOR.message_types_by_name['TellModelRequest']
_TELLMODELRESPONSE = DESCRIPTOR.message_types_by_name['TellModelResponse']
_DSSHUTDOWNREQUEST = DESCRIPTOR.message_types_by_name['DsShutdownRequest']
_DSSHUTDOWNRESPONSE = DESCRIPTOR.message_types_by_name['DsShutdownResponse']
_DSTESTCONNECTIONREQUEST = DESCRIPTOR.message_types_by_name['DsTestConnectionRequest']
_DSTESTCONNECTIONREQUEST_SECRETENTRY = _DSTESTCONNECTIONREQUEST.nested_types_by_name['SecretEntry']
_DSTESTCONNECTIONRESPONSE = DESCRIPTOR.message_types_by_name['DsTestConnectionResponse']
_DSSTUDYENDEDREQUEST = DESCRIPTOR.message_types_by_name['DsStudyEndedRequest']
_DSSTUDYENDEDREQUEST_SECRETENTRY = _DSSTUDYENDEDREQUEST.nested_types_by_name['SecretEntry']
_DSSTUDYENDEDRESPONSE = DESCRIPTOR.message_types_by_name['DsStudyEndedResponse']
_SAVEOPTIMIZERDBREQUEST = DESCRIPTOR.message_types_by_name['SaveOptimizerDBRequest']
_SAVEOPTIMIZERDBREQUEST_SECRETENTRY = _SAVEOPTIMIZERDBREQUEST.nested_types_by_name['SecretEntry']
_SAVEOPTIMIZERDBRESPONSE = DESCRIPTOR.message_types_by_name['SaveOptimizerDBResponse']
_DSGETDATABASESREQUEST = DESCRIPTOR.message_types_by_name['DsGetDatabasesRequest']
_DSGETDATABASESREQUEST_SECRETENTRY = _DSGETDATABASESREQUEST.nested_types_by_name['SecretEntry']
_DSGETDATABASESRESPONSE = DESCRIPTOR.message_types_by_name['DsGetDatabasesResponse']
_DSGETTABLESREQUEST = DESCRIPTOR.message_types_by_name['DsGetTablesRequest']
_DSGETTABLESREQUEST_SECRETENTRY = _DSGETTABLESREQUEST.nested_types_by_name['SecretEntry']
_DSGETTABLESRESPONSE = DESCRIPTOR.message_types_by_name['DsGetTablesResponse']
_DSEXECUTESQLREQUEST = DESCRIPTOR.message_types_by_name['DsExecuteSqlRequest']
_DSEXECUTESQLREQUEST_SECRETENTRY = _DSEXECUTESQLREQUEST.nested_types_by_name['SecretEntry']
_DSEXECUTESQLRESPONSE = DESCRIPTOR.message_types_by_name['DsExecuteSqlResponse']
_DSSNAPSHOTREQUEST = DESCRIPTOR.message_types_by_name['DsSnapshotRequest']
_DSSNAPSHOTREQUEST_DBSECRETENTRY = _DSSNAPSHOTREQUEST.nested_types_by_name['DbsecretEntry']
_DSSNAPSHOTREQUEST_STORAGESECRETENTRY = _DSSNAPSHOTREQUEST.nested_types_by_name['StoragesecretEntry']
_DSSNAPSHOTRESPONSE = DESCRIPTOR.message_types_by_name['DsSnapshotResponse']
_ASKMODELRESPONSE = DESCRIPTOR.message_types_by_name['AskModelResponse']
_GENTRAININGDATAREQUEST = DESCRIPTOR.message_types_by_name['GenTrainingDataRequest']
_GENTRAININGDATAREQUEST_STORAGESECRETENTRY = _GENTRAININGDATAREQUEST.nested_types_by_name['StorageSecretEntry']
_GENTRAININGDATAREQUEST_DBSECRETENTRY = _GENTRAININGDATAREQUEST.nested_types_by_name['DbSecretEntry']
_GENTRAININGDATARESPONSE = DESCRIPTOR.message_types_by_name['GenTrainingDataResponse']
_SYNCONLINESTOREREQUEST = DESCRIPTOR.message_types_by_name['SyncOnlineStoreRequest']
_SYNCONLINESTOREREQUEST_STORAGESECRETENTRY = _SYNCONLINESTOREREQUEST.nested_types_by_name['StorageSecretEntry']
_SYNCONLINESTOREREQUEST_DBSECRETENTRY = _SYNCONLINESTOREREQUEST.nested_types_by_name['DbSecretEntry']
_SYNCONLINESTORERESPONSE = DESCRIPTOR.message_types_by_name['SyncOnlineStoreResponse']
_GENONLINESTOREDATASETREQUEST = DESCRIPTOR.message_types_by_name['GenOnlineStoreDatasetRequest']
_GENONLINESTOREDATASETREQUEST_STORAGESECRETENTRY = _GENONLINESTOREDATASETREQUEST.nested_types_by_name['StorageSecretEntry']
_GENONLINESTOREDATASETREQUEST_DBSECRETENTRY = _GENONLINESTOREDATASETREQUEST.nested_types_by_name['DbSecretEntry']
_GENONLINESTOREDATASETRESPONSE = DESCRIPTOR.message_types_by_name['GenOnlineStoreDatasetResponse']
_BATCHPREDICTREQUEST = DESCRIPTOR.message_types_by_name['BatchPredictRequest']
_BATCHPREDICTREQUEST_STORAGESECRETENTRY = _BATCHPREDICTREQUEST.nested_types_by_name['StorageSecretEntry']
_BATCHPREDICTREQUEST_DBSECRETENTRY = _BATCHPREDICTREQUEST.nested_types_by_name['DbSecretEntry']
_BATCHPREDICTRESPONSE = DESCRIPTOR.message_types_by_name['BatchPredictResponse']
_SAVEDATASETREQUEST = DESCRIPTOR.message_types_by_name['SaveDatasetRequest']
_SAVEDATASETREQUEST_STORAGESECRETENTRY = _SAVEDATASETREQUEST.nested_types_by_name['StorageSecretEntry']
_SAVEDATASETREQUEST_DBSECRETENTRY = _SAVEDATASETREQUEST.nested_types_by_name['DbSecretEntry']
_SAVEMODELREQUEST = DESCRIPTOR.message_types_by_name['SaveModelRequest']
_SAVEMODELREQUEST_STORAGESECRETENTRY = _SAVEMODELREQUEST.nested_types_by_name['StorageSecretEntry']
_SAVEMODELREQUEST_DBSECRETENTRY = _SAVEMODELREQUEST.nested_types_by_name['DbSecretEntry']
_SAVEPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['SavePredictionRequest']
_SAVEPREDICTIONREQUEST_STORAGESECRETENTRY = _SAVEPREDICTIONREQUEST.nested_types_by_name['StorageSecretEntry']
_SAVEPREDICTIONREQUEST_DBSECRETENTRY = _SAVEPREDICTIONREQUEST.nested_types_by_name['DbSecretEntry']
_CREATEMETRICSSTOREREQUEST = DESCRIPTOR.message_types_by_name['CreateMetricsStoreRequest']
_CREATEMETRICSSTORERESPONSE = DESCRIPTOR.message_types_by_name['CreateMetricsStoreResponse']
_SAVERESPONSE = DESCRIPTOR.message_types_by_name['SaveResponse']
DsReadFileRequest = _reflection.GeneratedProtocolMessageType('DsReadFileRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSREADFILEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadFileRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSREADFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadFileRequest)
  })
_sym_db.RegisterMessage(DsReadFileRequest)
_sym_db.RegisterMessage(DsReadFileRequest.SecretEntry)

DsReadFeatureRequest = _reflection.GeneratedProtocolMessageType('DsReadFeatureRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSREADFEATUREREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadFeatureRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSREADFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadFeatureRequest)
  })
_sym_db.RegisterMessage(DsReadFeatureRequest)
_sym_db.RegisterMessage(DsReadFeatureRequest.SecretEntry)

DsWriteFileRequest = _reflection.GeneratedProtocolMessageType('DsWriteFileRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSWRITEFILEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsWriteFileRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSWRITEFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsWriteFileRequest)
  })
_sym_db.RegisterMessage(DsWriteFileRequest)
_sym_db.RegisterMessage(DsWriteFileRequest.SecretEntry)

DsReadAudioRequest = _reflection.GeneratedProtocolMessageType('DsReadAudioRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSREADAUDIOREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadAudioRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSREADAUDIOREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadAudioRequest)
  })
_sym_db.RegisterMessage(DsReadAudioRequest)
_sym_db.RegisterMessage(DsReadAudioRequest.SecretEntry)

DsReadTextCorpusRequest = _reflection.GeneratedProtocolMessageType('DsReadTextCorpusRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSREADTEXTCORPUSREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadTextCorpusRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSREADTEXTCORPUSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadTextCorpusRequest)
  })
_sym_db.RegisterMessage(DsReadTextCorpusRequest)
_sym_db.RegisterMessage(DsReadTextCorpusRequest.SecretEntry)

DsReadFromStoreResponse = _reflection.GeneratedProtocolMessageType('DsReadFromStoreResponse', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSREADFROMSTORERESPONSE_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSREADFROMSTORERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse)
  })
_sym_db.RegisterMessage(DsReadFromStoreResponse)
_sym_db.RegisterMessage(DsReadFromStoreResponse.SecretEntry)

DsRunDataPipelineRequest = _reflection.GeneratedProtocolMessageType('DsRunDataPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _DSRUNDATAPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsRunDataPipelineRequest)
  })
_sym_db.RegisterMessage(DsRunDataPipelineRequest)

DsRunDataPipelineResponse = _reflection.GeneratedProtocolMessageType('DsRunDataPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSRUNDATAPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsRunDataPipelineResponse)
  })
_sym_db.RegisterMessage(DsRunDataPipelineResponse)

DsRunRecipeRequest = _reflection.GeneratedProtocolMessageType('DsRunRecipeRequest', (_message.Message,), {

  'StorageSecretEntry' : _reflection.GeneratedProtocolMessageType('StorageSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSRUNRECIPEREQUEST_STORAGESECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeRequest.StorageSecretEntry)
    })
  ,

  'DbSecretEntry' : _reflection.GeneratedProtocolMessageType('DbSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSRUNRECIPEREQUEST_DBSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeRequest.DbSecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSRUNRECIPEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeRequest)
  })
_sym_db.RegisterMessage(DsRunRecipeRequest)
_sym_db.RegisterMessage(DsRunRecipeRequest.StorageSecretEntry)
_sym_db.RegisterMessage(DsRunRecipeRequest.DbSecretEntry)

DsRunRecipeResponse = _reflection.GeneratedProtocolMessageType('DsRunRecipeResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSRUNRECIPERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeResponse)
  })
_sym_db.RegisterMessage(DsRunRecipeResponse)

DsCreateRecipeProfileRequest = _reflection.GeneratedProtocolMessageType('DsCreateRecipeProfileRequest', (_message.Message,), {

  'StorageSecretEntry' : _reflection.GeneratedProtocolMessageType('StorageSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSCREATERECIPEPROFILEREQUEST_STORAGESECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileRequest.StorageSecretEntry)
    })
  ,

  'DbSecretEntry' : _reflection.GeneratedProtocolMessageType('DbSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSCREATERECIPEPROFILEREQUEST_DBSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileRequest.DbSecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSCREATERECIPEPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileRequest)
  })
_sym_db.RegisterMessage(DsCreateRecipeProfileRequest)
_sym_db.RegisterMessage(DsCreateRecipeProfileRequest.StorageSecretEntry)
_sym_db.RegisterMessage(DsCreateRecipeProfileRequest.DbSecretEntry)

DsCreateRecipeProfileResponse = _reflection.GeneratedProtocolMessageType('DsCreateRecipeProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSCREATERECIPEPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileResponse)
  })
_sym_db.RegisterMessage(DsCreateRecipeProfileResponse)

DataSourceResponse = _reflection.GeneratedProtocolMessageType('DataSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DataSourceResponse)
  })
_sym_db.RegisterMessage(DataSourceResponse)

DatasetResponse = _reflection.GeneratedProtocolMessageType('DatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _DATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DatasetResponse)
  })
_sym_db.RegisterMessage(DatasetResponse)

DsCreateDatasetProfileRequest = _reflection.GeneratedProtocolMessageType('DsCreateDatasetProfileRequest', (_message.Message,), {

  'StorageSecretEntry' : _reflection.GeneratedProtocolMessageType('StorageSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSCREATEDATASETPROFILEREQUEST_STORAGESECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileRequest.StorageSecretEntry)
    })
  ,

  'DbSecretEntry' : _reflection.GeneratedProtocolMessageType('DbSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSCREATEDATASETPROFILEREQUEST_DBSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileRequest.DbSecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSCREATEDATASETPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileRequest)
  })
_sym_db.RegisterMessage(DsCreateDatasetProfileRequest)
_sym_db.RegisterMessage(DsCreateDatasetProfileRequest.StorageSecretEntry)
_sym_db.RegisterMessage(DsCreateDatasetProfileRequest.DbSecretEntry)

DsCreateDatasetProfileResponse = _reflection.GeneratedProtocolMessageType('DsCreateDatasetProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSCREATEDATASETPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileResponse)
  })
_sym_db.RegisterMessage(DsCreateDatasetProfileResponse)

DsCreateModelProfileRequest = _reflection.GeneratedProtocolMessageType('DsCreateModelProfileRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSCREATEMODELPROFILEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileRequest.SecretEntry)
    })
  ,

  'DbSecretEntry' : _reflection.GeneratedProtocolMessageType('DbSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSCREATEMODELPROFILEREQUEST_DBSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileRequest.DbSecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSCREATEMODELPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileRequest)
  })
_sym_db.RegisterMessage(DsCreateModelProfileRequest)
_sym_db.RegisterMessage(DsCreateModelProfileRequest.SecretEntry)
_sym_db.RegisterMessage(DsCreateModelProfileRequest.DbSecretEntry)

DsCreateModelProfileResponse = _reflection.GeneratedProtocolMessageType('DsCreateModelProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSCREATEMODELPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileResponse)
  })
_sym_db.RegisterMessage(DsCreateModelProfileResponse)

DsMergeForecastFileRequest = _reflection.GeneratedProtocolMessageType('DsMergeForecastFileRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSMERGEFORECASTFILEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileRequest.SecretEntry)
    })
  ,

  'DbSecretEntry' : _reflection.GeneratedProtocolMessageType('DbSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSMERGEFORECASTFILEREQUEST_DBSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileRequest.DbSecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSMERGEFORECASTFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileRequest)
  })
_sym_db.RegisterMessage(DsMergeForecastFileRequest)
_sym_db.RegisterMessage(DsMergeForecastFileRequest.SecretEntry)
_sym_db.RegisterMessage(DsMergeForecastFileRequest.DbSecretEntry)

DsMergeForecastFileResponse = _reflection.GeneratedProtocolMessageType('DsMergeForecastFileResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSMERGEFORECASTFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileResponse)
  })
_sym_db.RegisterMessage(DsMergeForecastFileResponse)

DsCreateStudyProfileRequest = _reflection.GeneratedProtocolMessageType('DsCreateStudyProfileRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSCREATESTUDYPROFILEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileRequest.SecretEntry)
    })
  ,

  'DbSecretEntry' : _reflection.GeneratedProtocolMessageType('DbSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSCREATESTUDYPROFILEREQUEST_DBSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileRequest.DbSecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSCREATESTUDYPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileRequest)
  })
_sym_db.RegisterMessage(DsCreateStudyProfileRequest)
_sym_db.RegisterMessage(DsCreateStudyProfileRequest.SecretEntry)
_sym_db.RegisterMessage(DsCreateStudyProfileRequest.DbSecretEntry)

DsCreateStudyProfileResponse = _reflection.GeneratedProtocolMessageType('DsCreateStudyProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSCREATESTUDYPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileResponse)
  })
_sym_db.RegisterMessage(DsCreateStudyProfileResponse)

RunTestSuiteRequest = _reflection.GeneratedProtocolMessageType('RunTestSuiteRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _RUNTESTSUITEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.RunTestSuiteRequest.SecretEntry)
    })
  ,

  'DbSecretEntry' : _reflection.GeneratedProtocolMessageType('DbSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _RUNTESTSUITEREQUEST_DBSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.RunTestSuiteRequest.DbSecretEntry)
    })
  ,
  'DESCRIPTOR' : _RUNTESTSUITEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.RunTestSuiteRequest)
  })
_sym_db.RegisterMessage(RunTestSuiteRequest)
_sym_db.RegisterMessage(RunTestSuiteRequest.SecretEntry)
_sym_db.RegisterMessage(RunTestSuiteRequest.DbSecretEntry)

RunTestSuiteResponse = _reflection.GeneratedProtocolMessageType('RunTestSuiteResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNTESTSUITERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.RunTestSuiteResponse)
  })
_sym_db.RegisterMessage(RunTestSuiteResponse)

DsGenerateDatasetRequest = _reflection.GeneratedProtocolMessageType('DsGenerateDatasetRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSGENERATEDATASETREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetRequest.SecretEntry)
    })
  ,

  'DbSecretEntry' : _reflection.GeneratedProtocolMessageType('DbSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSGENERATEDATASETREQUEST_DBSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetRequest.DbSecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSGENERATEDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetRequest)
  })
_sym_db.RegisterMessage(DsGenerateDatasetRequest)
_sym_db.RegisterMessage(DsGenerateDatasetRequest.SecretEntry)
_sym_db.RegisterMessage(DsGenerateDatasetRequest.DbSecretEntry)

DsGenerateDatasetResponse = _reflection.GeneratedProtocolMessageType('DsGenerateDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSGENERATEDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetResponse)
  })
_sym_db.RegisterMessage(DsGenerateDatasetResponse)

DsSplitDatasetRequest = _reflection.GeneratedProtocolMessageType('DsSplitDatasetRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSSPLITDATASETREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetRequest.SecretEntry)
    })
  ,

  'DbSecretEntry' : _reflection.GeneratedProtocolMessageType('DbSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSSPLITDATASETREQUEST_DBSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetRequest.DbSecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSSPLITDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetRequest)
  })
_sym_db.RegisterMessage(DsSplitDatasetRequest)
_sym_db.RegisterMessage(DsSplitDatasetRequest.SecretEntry)
_sym_db.RegisterMessage(DsSplitDatasetRequest.DbSecretEntry)

DsSplitDatasetResponse = _reflection.GeneratedProtocolMessageType('DsSplitDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSSPLITDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetResponse)
  })
_sym_db.RegisterMessage(DsSplitDatasetResponse)

DsSplitDatasetToRungsRequest = _reflection.GeneratedProtocolMessageType('DsSplitDatasetToRungsRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSSPLITDATASETTORUNGSREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSSPLITDATASETTORUNGSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsRequest)
  })
_sym_db.RegisterMessage(DsSplitDatasetToRungsRequest)
_sym_db.RegisterMessage(DsSplitDatasetToRungsRequest.SecretEntry)

DsSplitDatasetToRungsResponse = _reflection.GeneratedProtocolMessageType('DsSplitDatasetToRungsResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSSPLITDATASETTORUNGSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsResponse)
  })
_sym_db.RegisterMessage(DsSplitDatasetToRungsResponse)

DsTransformRequest = _reflection.GeneratedProtocolMessageType('DsTransformRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSTRANSFORMREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsTransformRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSTRANSFORMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsTransformRequest)
  })
_sym_db.RegisterMessage(DsTransformRequest)
_sym_db.RegisterMessage(DsTransformRequest.SecretEntry)

DsTransformResponse = _reflection.GeneratedProtocolMessageType('DsTransformResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSTRANSFORMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsTransformResponse)
  })
_sym_db.RegisterMessage(DsTransformResponse)

DsCreateColumnProfileRequest = _reflection.GeneratedProtocolMessageType('DsCreateColumnProfileRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSCREATECOLUMNPROFILEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileRequest.SecretEntry)
    })
  ,

  'DbSecretEntry' : _reflection.GeneratedProtocolMessageType('DbSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSCREATECOLUMNPROFILEREQUEST_DBSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileRequest.DbSecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSCREATECOLUMNPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileRequest)
  })
_sym_db.RegisterMessage(DsCreateColumnProfileRequest)
_sym_db.RegisterMessage(DsCreateColumnProfileRequest.SecretEntry)
_sym_db.RegisterMessage(DsCreateColumnProfileRequest.DbSecretEntry)

DsCreateColumnProfileResponse = _reflection.GeneratedProtocolMessageType('DsCreateColumnProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSCREATECOLUMNPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileResponse)
  })
_sym_db.RegisterMessage(DsCreateColumnProfileResponse)

GroupByDatasetRequest = _reflection.GeneratedProtocolMessageType('GroupByDatasetRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _GROUPBYDATASETREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.GroupByDatasetRequest.SecretEntry)
    })
  ,

  'DbSecretEntry' : _reflection.GeneratedProtocolMessageType('DbSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _GROUPBYDATASETREQUEST_DBSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.GroupByDatasetRequest.DbSecretEntry)
    })
  ,
  'DESCRIPTOR' : _GROUPBYDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.GroupByDatasetRequest)
  })
_sym_db.RegisterMessage(GroupByDatasetRequest)
_sym_db.RegisterMessage(GroupByDatasetRequest.SecretEntry)
_sym_db.RegisterMessage(GroupByDatasetRequest.DbSecretEntry)

GroupByDatasetResponse = _reflection.GeneratedProtocolMessageType('GroupByDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _GROUPBYDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.GroupByDatasetResponse)
  })
_sym_db.RegisterMessage(GroupByDatasetResponse)

DsInferSchemaRequest = _reflection.GeneratedProtocolMessageType('DsInferSchemaRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSINFERSCHEMAREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSINFERSCHEMAREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaRequest)
  })
_sym_db.RegisterMessage(DsInferSchemaRequest)
_sym_db.RegisterMessage(DsInferSchemaRequest.SecretEntry)

DsInferSchemaResponse = _reflection.GeneratedProtocolMessageType('DsInferSchemaResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSINFERSCHEMARESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaResponse)
  })
_sym_db.RegisterMessage(DsInferSchemaResponse)

DsGetTableViewRequest = _reflection.GeneratedProtocolMessageType('DsGetTableViewRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSGETTABLEVIEWREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewRequest.SecretEntry)
    })
  ,

  'DbSecretEntry' : _reflection.GeneratedProtocolMessageType('DbSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSGETTABLEVIEWREQUEST_DBSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewRequest.DbSecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSGETTABLEVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewRequest)
  })
_sym_db.RegisterMessage(DsGetTableViewRequest)
_sym_db.RegisterMessage(DsGetTableViewRequest.SecretEntry)
_sym_db.RegisterMessage(DsGetTableViewRequest.DbSecretEntry)

DsGetTableViewResponse = _reflection.GeneratedProtocolMessageType('DsGetTableViewResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSGETTABLEVIEWRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewResponse)
  })
_sym_db.RegisterMessage(DsGetTableViewResponse)

CreateModelReportRequest = _reflection.GeneratedProtocolMessageType('CreateModelReportRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEMODELREPORTREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateModelReportRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEMODELREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateModelReportRequest)
  })
_sym_db.RegisterMessage(CreateModelReportRequest)
_sym_db.RegisterMessage(CreateModelReportRequest.SecretEntry)

CreateForecastReportRequest = _reflection.GeneratedProtocolMessageType('CreateForecastReportRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEFORECASTREPORTREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest.SecretEntry)
    })
  ,

  'DbSecretEntry' : _reflection.GeneratedProtocolMessageType('DbSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEFORECASTREPORTREQUEST_DBSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest.DbSecretEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEFORECASTREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest)
  })
_sym_db.RegisterMessage(CreateForecastReportRequest)
_sym_db.RegisterMessage(CreateForecastReportRequest.SecretEntry)
_sym_db.RegisterMessage(CreateForecastReportRequest.DbSecretEntry)

CreateSummaryReportRequest = _reflection.GeneratedProtocolMessageType('CreateSummaryReportRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATESUMMARYREPORTREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateSummaryReportRequest.SecretEntry)
    })
  ,

  'DbSecretEntry' : _reflection.GeneratedProtocolMessageType('DbSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATESUMMARYREPORTREQUEST_DBSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateSummaryReportRequest.DbSecretEntry)
    })
  ,
  'DESCRIPTOR' : _CREATESUMMARYREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateSummaryReportRequest)
  })
_sym_db.RegisterMessage(CreateSummaryReportRequest)
_sym_db.RegisterMessage(CreateSummaryReportRequest.SecretEntry)
_sym_db.RegisterMessage(CreateSummaryReportRequest.DbSecretEntry)

CreateReportResponse = _reflection.GeneratedProtocolMessageType('CreateReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateReportResponse)
  })
_sym_db.RegisterMessage(CreateReportResponse)

CreateDatasetReportRequest = _reflection.GeneratedProtocolMessageType('CreateDatasetReportRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEDATASETREPORTREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateDatasetReportRequest.SecretEntry)
    })
  ,

  'DbSecretEntry' : _reflection.GeneratedProtocolMessageType('DbSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEDATASETREPORTREQUEST_DBSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateDatasetReportRequest.DbSecretEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEDATASETREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateDatasetReportRequest)
  })
_sym_db.RegisterMessage(CreateDatasetReportRequest)
_sym_db.RegisterMessage(CreateDatasetReportRequest.SecretEntry)
_sym_db.RegisterMessage(CreateDatasetReportRequest.DbSecretEntry)

CreateStudyReportRequest = _reflection.GeneratedProtocolMessageType('CreateStudyReportRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATESTUDYREPORTREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest.SecretEntry)
    })
  ,

  'DbSecretEntry' : _reflection.GeneratedProtocolMessageType('DbSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATESTUDYREPORTREQUEST_DBSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest.DbSecretEntry)
    })
  ,
  'DESCRIPTOR' : _CREATESTUDYREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest)
  })
_sym_db.RegisterMessage(CreateStudyReportRequest)
_sym_db.RegisterMessage(CreateStudyReportRequest.SecretEntry)
_sym_db.RegisterMessage(CreateStudyReportRequest.DbSecretEntry)

AskModelRequest = _reflection.GeneratedProtocolMessageType('AskModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _ASKMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.AskModelRequest)
  })
_sym_db.RegisterMessage(AskModelRequest)

GetTimeSeriesDatasetKeysRequest = _reflection.GeneratedProtocolMessageType('GetTimeSeriesDatasetKeysRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTIMESERIESDATASETKEYSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.GetTimeSeriesDatasetKeysRequest)
  })
_sym_db.RegisterMessage(GetTimeSeriesDatasetKeysRequest)

GetTimeSeriesDatasetKeysResponse = _reflection.GeneratedProtocolMessageType('GetTimeSeriesDatasetKeysResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTIMESERIESDATASETKEYSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.GetTimeSeriesDatasetKeysResponse)
  })
_sym_db.RegisterMessage(GetTimeSeriesDatasetKeysResponse)

AskForecastModelRequest = _reflection.GeneratedProtocolMessageType('AskForecastModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _ASKFORECASTMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.AskForecastModelRequest)
  })
_sym_db.RegisterMessage(AskForecastModelRequest)

AskForecastModelResponse = _reflection.GeneratedProtocolMessageType('AskForecastModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _ASKFORECASTMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.AskForecastModelResponse)
  })
_sym_db.RegisterMessage(AskForecastModelResponse)

AskEnsembleRequest = _reflection.GeneratedProtocolMessageType('AskEnsembleRequest', (_message.Message,), {
  'DESCRIPTOR' : _ASKENSEMBLEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.AskEnsembleRequest)
  })
_sym_db.RegisterMessage(AskEnsembleRequest)

AskEnsembleResponse = _reflection.GeneratedProtocolMessageType('AskEnsembleResponse', (_message.Message,), {
  'DESCRIPTOR' : _ASKENSEMBLERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.AskEnsembleResponse)
  })
_sym_db.RegisterMessage(AskEnsembleResponse)

AskBaselineRequest = _reflection.GeneratedProtocolMessageType('AskBaselineRequest', (_message.Message,), {
  'DESCRIPTOR' : _ASKBASELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.AskBaselineRequest)
  })
_sym_db.RegisterMessage(AskBaselineRequest)

AskBaselineResponse = _reflection.GeneratedProtocolMessageType('AskBaselineResponse', (_message.Message,), {
  'DESCRIPTOR' : _ASKBASELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.AskBaselineResponse)
  })
_sym_db.RegisterMessage(AskBaselineResponse)

AskAllModelsForTaskRequest = _reflection.GeneratedProtocolMessageType('AskAllModelsForTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _ASKALLMODELSFORTASKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.AskAllModelsForTaskRequest)
  })
_sym_db.RegisterMessage(AskAllModelsForTaskRequest)

AskAllModelsForTaskResponse = _reflection.GeneratedProtocolMessageType('AskAllModelsForTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _ASKALLMODELSFORTASKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.AskAllModelsForTaskResponse)
  })
_sym_db.RegisterMessage(AskAllModelsForTaskResponse)

TellModelRequest = _reflection.GeneratedProtocolMessageType('TellModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _TELLMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.TellModelRequest)
  })
_sym_db.RegisterMessage(TellModelRequest)

TellModelResponse = _reflection.GeneratedProtocolMessageType('TellModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _TELLMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.TellModelResponse)
  })
_sym_db.RegisterMessage(TellModelResponse)

DsShutdownRequest = _reflection.GeneratedProtocolMessageType('DsShutdownRequest', (_message.Message,), {
  'DESCRIPTOR' : _DSSHUTDOWNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsShutdownRequest)
  })
_sym_db.RegisterMessage(DsShutdownRequest)

DsShutdownResponse = _reflection.GeneratedProtocolMessageType('DsShutdownResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSSHUTDOWNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsShutdownResponse)
  })
_sym_db.RegisterMessage(DsShutdownResponse)

DsTestConnectionRequest = _reflection.GeneratedProtocolMessageType('DsTestConnectionRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSTESTCONNECTIONREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSTESTCONNECTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionRequest)
  })
_sym_db.RegisterMessage(DsTestConnectionRequest)
_sym_db.RegisterMessage(DsTestConnectionRequest.SecretEntry)

DsTestConnectionResponse = _reflection.GeneratedProtocolMessageType('DsTestConnectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSTESTCONNECTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionResponse)
  })
_sym_db.RegisterMessage(DsTestConnectionResponse)

DsStudyEndedRequest = _reflection.GeneratedProtocolMessageType('DsStudyEndedRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSSTUDYENDEDREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSSTUDYENDEDREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedRequest)
  })
_sym_db.RegisterMessage(DsStudyEndedRequest)
_sym_db.RegisterMessage(DsStudyEndedRequest.SecretEntry)

DsStudyEndedResponse = _reflection.GeneratedProtocolMessageType('DsStudyEndedResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSSTUDYENDEDRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedResponse)
  })
_sym_db.RegisterMessage(DsStudyEndedResponse)

SaveOptimizerDBRequest = _reflection.GeneratedProtocolMessageType('SaveOptimizerDBRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _SAVEOPTIMIZERDBREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _SAVEOPTIMIZERDBREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBRequest)
  })
_sym_db.RegisterMessage(SaveOptimizerDBRequest)
_sym_db.RegisterMessage(SaveOptimizerDBRequest.SecretEntry)

SaveOptimizerDBResponse = _reflection.GeneratedProtocolMessageType('SaveOptimizerDBResponse', (_message.Message,), {
  'DESCRIPTOR' : _SAVEOPTIMIZERDBRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBResponse)
  })
_sym_db.RegisterMessage(SaveOptimizerDBResponse)

DsGetDatabasesRequest = _reflection.GeneratedProtocolMessageType('DsGetDatabasesRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSGETDATABASESREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetDatabasesRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSGETDATABASESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetDatabasesRequest)
  })
_sym_db.RegisterMessage(DsGetDatabasesRequest)
_sym_db.RegisterMessage(DsGetDatabasesRequest.SecretEntry)

DsGetDatabasesResponse = _reflection.GeneratedProtocolMessageType('DsGetDatabasesResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSGETDATABASESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetDatabasesResponse)
  })
_sym_db.RegisterMessage(DsGetDatabasesResponse)

DsGetTablesRequest = _reflection.GeneratedProtocolMessageType('DsGetTablesRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSGETTABLESREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetTablesRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSGETTABLESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetTablesRequest)
  })
_sym_db.RegisterMessage(DsGetTablesRequest)
_sym_db.RegisterMessage(DsGetTablesRequest.SecretEntry)

DsGetTablesResponse = _reflection.GeneratedProtocolMessageType('DsGetTablesResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSGETTABLESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetTablesResponse)
  })
_sym_db.RegisterMessage(DsGetTablesResponse)

DsExecuteSqlRequest = _reflection.GeneratedProtocolMessageType('DsExecuteSqlRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSEXECUTESQLREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSEXECUTESQLREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlRequest)
  })
_sym_db.RegisterMessage(DsExecuteSqlRequest)
_sym_db.RegisterMessage(DsExecuteSqlRequest.SecretEntry)

DsExecuteSqlResponse = _reflection.GeneratedProtocolMessageType('DsExecuteSqlResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSEXECUTESQLRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlResponse)
  })
_sym_db.RegisterMessage(DsExecuteSqlResponse)

DsSnapshotRequest = _reflection.GeneratedProtocolMessageType('DsSnapshotRequest', (_message.Message,), {

  'DbsecretEntry' : _reflection.GeneratedProtocolMessageType('DbsecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSSNAPSHOTREQUEST_DBSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.DbsecretEntry)
    })
  ,

  'StoragesecretEntry' : _reflection.GeneratedProtocolMessageType('StoragesecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSSNAPSHOTREQUEST_STORAGESECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.StoragesecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSSNAPSHOTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest)
  })
_sym_db.RegisterMessage(DsSnapshotRequest)
_sym_db.RegisterMessage(DsSnapshotRequest.DbsecretEntry)
_sym_db.RegisterMessage(DsSnapshotRequest.StoragesecretEntry)

DsSnapshotResponse = _reflection.GeneratedProtocolMessageType('DsSnapshotResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSSNAPSHOTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSnapshotResponse)
  })
_sym_db.RegisterMessage(DsSnapshotResponse)

AskModelResponse = _reflection.GeneratedProtocolMessageType('AskModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _ASKMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.AskModelResponse)
  })
_sym_db.RegisterMessage(AskModelResponse)

GenTrainingDataRequest = _reflection.GeneratedProtocolMessageType('GenTrainingDataRequest', (_message.Message,), {

  'StorageSecretEntry' : _reflection.GeneratedProtocolMessageType('StorageSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _GENTRAININGDATAREQUEST_STORAGESECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.GenTrainingDataRequest.StorageSecretEntry)
    })
  ,

  'DbSecretEntry' : _reflection.GeneratedProtocolMessageType('DbSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _GENTRAININGDATAREQUEST_DBSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.GenTrainingDataRequest.DbSecretEntry)
    })
  ,
  'DESCRIPTOR' : _GENTRAININGDATAREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.GenTrainingDataRequest)
  })
_sym_db.RegisterMessage(GenTrainingDataRequest)
_sym_db.RegisterMessage(GenTrainingDataRequest.StorageSecretEntry)
_sym_db.RegisterMessage(GenTrainingDataRequest.DbSecretEntry)

GenTrainingDataResponse = _reflection.GeneratedProtocolMessageType('GenTrainingDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _GENTRAININGDATARESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.GenTrainingDataResponse)
  })
_sym_db.RegisterMessage(GenTrainingDataResponse)

SyncOnlineStoreRequest = _reflection.GeneratedProtocolMessageType('SyncOnlineStoreRequest', (_message.Message,), {

  'StorageSecretEntry' : _reflection.GeneratedProtocolMessageType('StorageSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _SYNCONLINESTOREREQUEST_STORAGESECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.SyncOnlineStoreRequest.StorageSecretEntry)
    })
  ,

  'DbSecretEntry' : _reflection.GeneratedProtocolMessageType('DbSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _SYNCONLINESTOREREQUEST_DBSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.SyncOnlineStoreRequest.DbSecretEntry)
    })
  ,
  'DESCRIPTOR' : _SYNCONLINESTOREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.SyncOnlineStoreRequest)
  })
_sym_db.RegisterMessage(SyncOnlineStoreRequest)
_sym_db.RegisterMessage(SyncOnlineStoreRequest.StorageSecretEntry)
_sym_db.RegisterMessage(SyncOnlineStoreRequest.DbSecretEntry)

SyncOnlineStoreResponse = _reflection.GeneratedProtocolMessageType('SyncOnlineStoreResponse', (_message.Message,), {
  'DESCRIPTOR' : _SYNCONLINESTORERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.SyncOnlineStoreResponse)
  })
_sym_db.RegisterMessage(SyncOnlineStoreResponse)

GenOnlineStoreDatasetRequest = _reflection.GeneratedProtocolMessageType('GenOnlineStoreDatasetRequest', (_message.Message,), {

  'StorageSecretEntry' : _reflection.GeneratedProtocolMessageType('StorageSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _GENONLINESTOREDATASETREQUEST_STORAGESECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.GenOnlineStoreDatasetRequest.StorageSecretEntry)
    })
  ,

  'DbSecretEntry' : _reflection.GeneratedProtocolMessageType('DbSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _GENONLINESTOREDATASETREQUEST_DBSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.GenOnlineStoreDatasetRequest.DbSecretEntry)
    })
  ,
  'DESCRIPTOR' : _GENONLINESTOREDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.GenOnlineStoreDatasetRequest)
  })
_sym_db.RegisterMessage(GenOnlineStoreDatasetRequest)
_sym_db.RegisterMessage(GenOnlineStoreDatasetRequest.StorageSecretEntry)
_sym_db.RegisterMessage(GenOnlineStoreDatasetRequest.DbSecretEntry)

GenOnlineStoreDatasetResponse = _reflection.GeneratedProtocolMessageType('GenOnlineStoreDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _GENONLINESTOREDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.GenOnlineStoreDatasetResponse)
  })
_sym_db.RegisterMessage(GenOnlineStoreDatasetResponse)

BatchPredictRequest = _reflection.GeneratedProtocolMessageType('BatchPredictRequest', (_message.Message,), {

  'StorageSecretEntry' : _reflection.GeneratedProtocolMessageType('StorageSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _BATCHPREDICTREQUEST_STORAGESECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.BatchPredictRequest.StorageSecretEntry)
    })
  ,

  'DbSecretEntry' : _reflection.GeneratedProtocolMessageType('DbSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _BATCHPREDICTREQUEST_DBSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.BatchPredictRequest.DbSecretEntry)
    })
  ,
  'DESCRIPTOR' : _BATCHPREDICTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.BatchPredictRequest)
  })
_sym_db.RegisterMessage(BatchPredictRequest)
_sym_db.RegisterMessage(BatchPredictRequest.StorageSecretEntry)
_sym_db.RegisterMessage(BatchPredictRequest.DbSecretEntry)

BatchPredictResponse = _reflection.GeneratedProtocolMessageType('BatchPredictResponse', (_message.Message,), {
  'DESCRIPTOR' : _BATCHPREDICTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.BatchPredictResponse)
  })
_sym_db.RegisterMessage(BatchPredictResponse)

SaveDatasetRequest = _reflection.GeneratedProtocolMessageType('SaveDatasetRequest', (_message.Message,), {

  'StorageSecretEntry' : _reflection.GeneratedProtocolMessageType('StorageSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _SAVEDATASETREQUEST_STORAGESECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.SaveDatasetRequest.StorageSecretEntry)
    })
  ,

  'DbSecretEntry' : _reflection.GeneratedProtocolMessageType('DbSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _SAVEDATASETREQUEST_DBSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.SaveDatasetRequest.DbSecretEntry)
    })
  ,
  'DESCRIPTOR' : _SAVEDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.SaveDatasetRequest)
  })
_sym_db.RegisterMessage(SaveDatasetRequest)
_sym_db.RegisterMessage(SaveDatasetRequest.StorageSecretEntry)
_sym_db.RegisterMessage(SaveDatasetRequest.DbSecretEntry)

SaveModelRequest = _reflection.GeneratedProtocolMessageType('SaveModelRequest', (_message.Message,), {

  'StorageSecretEntry' : _reflection.GeneratedProtocolMessageType('StorageSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _SAVEMODELREQUEST_STORAGESECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.SaveModelRequest.StorageSecretEntry)
    })
  ,

  'DbSecretEntry' : _reflection.GeneratedProtocolMessageType('DbSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _SAVEMODELREQUEST_DBSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.SaveModelRequest.DbSecretEntry)
    })
  ,
  'DESCRIPTOR' : _SAVEMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.SaveModelRequest)
  })
_sym_db.RegisterMessage(SaveModelRequest)
_sym_db.RegisterMessage(SaveModelRequest.StorageSecretEntry)
_sym_db.RegisterMessage(SaveModelRequest.DbSecretEntry)

SavePredictionRequest = _reflection.GeneratedProtocolMessageType('SavePredictionRequest', (_message.Message,), {

  'StorageSecretEntry' : _reflection.GeneratedProtocolMessageType('StorageSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _SAVEPREDICTIONREQUEST_STORAGESECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.SavePredictionRequest.StorageSecretEntry)
    })
  ,

  'DbSecretEntry' : _reflection.GeneratedProtocolMessageType('DbSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _SAVEPREDICTIONREQUEST_DBSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.SavePredictionRequest.DbSecretEntry)
    })
  ,
  'DESCRIPTOR' : _SAVEPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.SavePredictionRequest)
  })
_sym_db.RegisterMessage(SavePredictionRequest)
_sym_db.RegisterMessage(SavePredictionRequest.StorageSecretEntry)
_sym_db.RegisterMessage(SavePredictionRequest.DbSecretEntry)

CreateMetricsStoreRequest = _reflection.GeneratedProtocolMessageType('CreateMetricsStoreRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMETRICSSTOREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateMetricsStoreRequest)
  })
_sym_db.RegisterMessage(CreateMetricsStoreRequest)

CreateMetricsStoreResponse = _reflection.GeneratedProtocolMessageType('CreateMetricsStoreResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMETRICSSTORERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateMetricsStoreResponse)
  })
_sym_db.RegisterMessage(CreateMetricsStoreResponse)

SaveResponse = _reflection.GeneratedProtocolMessageType('SaveResponse', (_message.Message,), {
  'DESCRIPTOR' : _SAVERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.SaveResponse)
  })
_sym_db.RegisterMessage(SaveResponse)

_DATASERVICE = DESCRIPTOR.services_by_name['DataService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z.github.com/metaprov/modelaapi/services/data/v1'
  _DSREADFILEREQUEST_SECRETENTRY._options = None
  _DSREADFILEREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSREADFEATUREREQUEST_SECRETENTRY._options = None
  _DSREADFEATUREREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSWRITEFILEREQUEST_SECRETENTRY._options = None
  _DSWRITEFILEREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSREADAUDIOREQUEST_SECRETENTRY._options = None
  _DSREADAUDIOREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSREADTEXTCORPUSREQUEST_SECRETENTRY._options = None
  _DSREADTEXTCORPUSREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSREADFROMSTORERESPONSE_SECRETENTRY._options = None
  _DSREADFROMSTORERESPONSE_SECRETENTRY._serialized_options = b'8\001'
  _DSRUNRECIPEREQUEST_STORAGESECRETENTRY._options = None
  _DSRUNRECIPEREQUEST_STORAGESECRETENTRY._serialized_options = b'8\001'
  _DSRUNRECIPEREQUEST_DBSECRETENTRY._options = None
  _DSRUNRECIPEREQUEST_DBSECRETENTRY._serialized_options = b'8\001'
  _DSCREATERECIPEPROFILEREQUEST_STORAGESECRETENTRY._options = None
  _DSCREATERECIPEPROFILEREQUEST_STORAGESECRETENTRY._serialized_options = b'8\001'
  _DSCREATERECIPEPROFILEREQUEST_DBSECRETENTRY._options = None
  _DSCREATERECIPEPROFILEREQUEST_DBSECRETENTRY._serialized_options = b'8\001'
  _DSCREATEDATASETPROFILEREQUEST_STORAGESECRETENTRY._options = None
  _DSCREATEDATASETPROFILEREQUEST_STORAGESECRETENTRY._serialized_options = b'8\001'
  _DSCREATEDATASETPROFILEREQUEST_DBSECRETENTRY._options = None
  _DSCREATEDATASETPROFILEREQUEST_DBSECRETENTRY._serialized_options = b'8\001'
  _DSCREATEMODELPROFILEREQUEST_SECRETENTRY._options = None
  _DSCREATEMODELPROFILEREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSCREATEMODELPROFILEREQUEST_DBSECRETENTRY._options = None
  _DSCREATEMODELPROFILEREQUEST_DBSECRETENTRY._serialized_options = b'8\001'
  _DSMERGEFORECASTFILEREQUEST_SECRETENTRY._options = None
  _DSMERGEFORECASTFILEREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSMERGEFORECASTFILEREQUEST_DBSECRETENTRY._options = None
  _DSMERGEFORECASTFILEREQUEST_DBSECRETENTRY._serialized_options = b'8\001'
  _DSCREATESTUDYPROFILEREQUEST_SECRETENTRY._options = None
  _DSCREATESTUDYPROFILEREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSCREATESTUDYPROFILEREQUEST_DBSECRETENTRY._options = None
  _DSCREATESTUDYPROFILEREQUEST_DBSECRETENTRY._serialized_options = b'8\001'
  _RUNTESTSUITEREQUEST_SECRETENTRY._options = None
  _RUNTESTSUITEREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _RUNTESTSUITEREQUEST_DBSECRETENTRY._options = None
  _RUNTESTSUITEREQUEST_DBSECRETENTRY._serialized_options = b'8\001'
  _DSGENERATEDATASETREQUEST_SECRETENTRY._options = None
  _DSGENERATEDATASETREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSGENERATEDATASETREQUEST_DBSECRETENTRY._options = None
  _DSGENERATEDATASETREQUEST_DBSECRETENTRY._serialized_options = b'8\001'
  _DSSPLITDATASETREQUEST_SECRETENTRY._options = None
  _DSSPLITDATASETREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSSPLITDATASETREQUEST_DBSECRETENTRY._options = None
  _DSSPLITDATASETREQUEST_DBSECRETENTRY._serialized_options = b'8\001'
  _DSSPLITDATASETTORUNGSREQUEST_SECRETENTRY._options = None
  _DSSPLITDATASETTORUNGSREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSTRANSFORMREQUEST_SECRETENTRY._options = None
  _DSTRANSFORMREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSCREATECOLUMNPROFILEREQUEST_SECRETENTRY._options = None
  _DSCREATECOLUMNPROFILEREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSCREATECOLUMNPROFILEREQUEST_DBSECRETENTRY._options = None
  _DSCREATECOLUMNPROFILEREQUEST_DBSECRETENTRY._serialized_options = b'8\001'
  _GROUPBYDATASETREQUEST_SECRETENTRY._options = None
  _GROUPBYDATASETREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _GROUPBYDATASETREQUEST_DBSECRETENTRY._options = None
  _GROUPBYDATASETREQUEST_DBSECRETENTRY._serialized_options = b'8\001'
  _DSINFERSCHEMAREQUEST_SECRETENTRY._options = None
  _DSINFERSCHEMAREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSGETTABLEVIEWREQUEST_SECRETENTRY._options = None
  _DSGETTABLEVIEWREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSGETTABLEVIEWREQUEST_DBSECRETENTRY._options = None
  _DSGETTABLEVIEWREQUEST_DBSECRETENTRY._serialized_options = b'8\001'
  _CREATEMODELREPORTREQUEST_SECRETENTRY._options = None
  _CREATEMODELREPORTREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _CREATEFORECASTREPORTREQUEST_SECRETENTRY._options = None
  _CREATEFORECASTREPORTREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _CREATEFORECASTREPORTREQUEST_DBSECRETENTRY._options = None
  _CREATEFORECASTREPORTREQUEST_DBSECRETENTRY._serialized_options = b'8\001'
  _CREATESUMMARYREPORTREQUEST_SECRETENTRY._options = None
  _CREATESUMMARYREPORTREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _CREATESUMMARYREPORTREQUEST_DBSECRETENTRY._options = None
  _CREATESUMMARYREPORTREQUEST_DBSECRETENTRY._serialized_options = b'8\001'
  _CREATEDATASETREPORTREQUEST_SECRETENTRY._options = None
  _CREATEDATASETREPORTREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _CREATEDATASETREPORTREQUEST_DBSECRETENTRY._options = None
  _CREATEDATASETREPORTREQUEST_DBSECRETENTRY._serialized_options = b'8\001'
  _CREATESTUDYREPORTREQUEST_SECRETENTRY._options = None
  _CREATESTUDYREPORTREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _CREATESTUDYREPORTREQUEST_DBSECRETENTRY._options = None
  _CREATESTUDYREPORTREQUEST_DBSECRETENTRY._serialized_options = b'8\001'
  _DSTESTCONNECTIONREQUEST_SECRETENTRY._options = None
  _DSTESTCONNECTIONREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSSTUDYENDEDREQUEST_SECRETENTRY._options = None
  _DSSTUDYENDEDREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _SAVEOPTIMIZERDBREQUEST_SECRETENTRY._options = None
  _SAVEOPTIMIZERDBREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSGETDATABASESREQUEST_SECRETENTRY._options = None
  _DSGETDATABASESREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSGETTABLESREQUEST_SECRETENTRY._options = None
  _DSGETTABLESREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSEXECUTESQLREQUEST_SECRETENTRY._options = None
  _DSEXECUTESQLREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _DSSNAPSHOTREQUEST_DBSECRETENTRY._options = None
  _DSSNAPSHOTREQUEST_DBSECRETENTRY._serialized_options = b'8\001'
  _DSSNAPSHOTREQUEST_STORAGESECRETENTRY._options = None
  _DSSNAPSHOTREQUEST_STORAGESECRETENTRY._serialized_options = b'8\001'
  _GENTRAININGDATAREQUEST_STORAGESECRETENTRY._options = None
  _GENTRAININGDATAREQUEST_STORAGESECRETENTRY._serialized_options = b'8\001'
  _GENTRAININGDATAREQUEST_DBSECRETENTRY._options = None
  _GENTRAININGDATAREQUEST_DBSECRETENTRY._serialized_options = b'8\001'
  _SYNCONLINESTOREREQUEST_STORAGESECRETENTRY._options = None
  _SYNCONLINESTOREREQUEST_STORAGESECRETENTRY._serialized_options = b'8\001'
  _SYNCONLINESTOREREQUEST_DBSECRETENTRY._options = None
  _SYNCONLINESTOREREQUEST_DBSECRETENTRY._serialized_options = b'8\001'
  _GENONLINESTOREDATASETREQUEST_STORAGESECRETENTRY._options = None
  _GENONLINESTOREDATASETREQUEST_STORAGESECRETENTRY._serialized_options = b'8\001'
  _GENONLINESTOREDATASETREQUEST_DBSECRETENTRY._options = None
  _GENONLINESTOREDATASETREQUEST_DBSECRETENTRY._serialized_options = b'8\001'
  _BATCHPREDICTREQUEST_STORAGESECRETENTRY._options = None
  _BATCHPREDICTREQUEST_STORAGESECRETENTRY._serialized_options = b'8\001'
  _BATCHPREDICTREQUEST_DBSECRETENTRY._options = None
  _BATCHPREDICTREQUEST_DBSECRETENTRY._serialized_options = b'8\001'
  _SAVEDATASETREQUEST_STORAGESECRETENTRY._options = None
  _SAVEDATASETREQUEST_STORAGESECRETENTRY._serialized_options = b'8\001'
  _SAVEDATASETREQUEST_DBSECRETENTRY._options = None
  _SAVEDATASETREQUEST_DBSECRETENTRY._serialized_options = b'8\001'
  _SAVEMODELREQUEST_STORAGESECRETENTRY._options = None
  _SAVEMODELREQUEST_STORAGESECRETENTRY._serialized_options = b'8\001'
  _SAVEMODELREQUEST_DBSECRETENTRY._options = None
  _SAVEMODELREQUEST_DBSECRETENTRY._serialized_options = b'8\001'
  _SAVEPREDICTIONREQUEST_STORAGESECRETENTRY._options = None
  _SAVEPREDICTIONREQUEST_STORAGESECRETENTRY._serialized_options = b'8\001'
  _SAVEPREDICTIONREQUEST_DBSECRETENTRY._options = None
  _SAVEPREDICTIONREQUEST_DBSECRETENTRY._serialized_options = b'8\001'
  _DSREADFILEREQUEST._serialized_start=572
  _DSREADFILEREQUEST._serialized_end=1081
  _DSREADFILEREQUEST_SECRETENTRY._serialized_start=1036
  _DSREADFILEREQUEST_SECRETENTRY._serialized_end=1081
  _DSREADFEATUREREQUEST._serialized_start=1084
  _DSREADFEATUREREQUEST._serialized_end=1599
  _DSREADFEATUREREQUEST_SECRETENTRY._serialized_start=1036
  _DSREADFEATUREREQUEST_SECRETENTRY._serialized_end=1081
  _DSWRITEFILEREQUEST._serialized_start=1602
  _DSWRITEFILEREQUEST._serialized_end=2193
  _DSWRITEFILEREQUEST_SECRETENTRY._serialized_start=1036
  _DSWRITEFILEREQUEST_SECRETENTRY._serialized_end=1081
  _DSREADAUDIOREQUEST._serialized_start=2196
  _DSREADAUDIOREQUEST._serialized_end=2532
  _DSREADAUDIOREQUEST_SECRETENTRY._serialized_start=1036
  _DSREADAUDIOREQUEST_SECRETENTRY._serialized_end=1081
  _DSREADTEXTCORPUSREQUEST._serialized_start=2535
  _DSREADTEXTCORPUSREQUEST._serialized_end=3056
  _DSREADTEXTCORPUSREQUEST_SECRETENTRY._serialized_start=1036
  _DSREADTEXTCORPUSREQUEST_SECRETENTRY._serialized_end=1081
  _DSREADFROMSTORERESPONSE._serialized_start=3059
  _DSREADFROMSTORERESPONSE._serialized_end=3659
  _DSREADFROMSTORERESPONSE_SECRETENTRY._serialized_start=1036
  _DSREADFROMSTORERESPONSE_SECRETENTRY._serialized_end=1081
  _DSRUNDATAPIPELINEREQUEST._serialized_start=3661
  _DSRUNDATAPIPELINEREQUEST._serialized_end=3773
  _DSRUNDATAPIPELINERESPONSE._serialized_start=3775
  _DSRUNDATAPIPELINERESPONSE._serialized_end=3881
  _DSRUNRECIPEREQUEST._serialized_start=3884
  _DSRUNRECIPEREQUEST._serialized_end=4989
  _DSRUNRECIPEREQUEST_STORAGESECRETENTRY._serialized_start=4888
  _DSRUNRECIPEREQUEST_STORAGESECRETENTRY._serialized_end=4940
  _DSRUNRECIPEREQUEST_DBSECRETENTRY._serialized_start=4942
  _DSRUNRECIPEREQUEST_DBSECRETENTRY._serialized_end=4989
  _DSRUNRECIPERESPONSE._serialized_start=4991
  _DSRUNRECIPERESPONSE._serialized_end=5090
  _DSCREATERECIPEPROFILEREQUEST._serialized_start=5093
  _DSCREATERECIPEPROFILEREQUEST._serialized_end=6144
  _DSCREATERECIPEPROFILEREQUEST_STORAGESECRETENTRY._serialized_start=4888
  _DSCREATERECIPEPROFILEREQUEST_STORAGESECRETENTRY._serialized_end=4940
  _DSCREATERECIPEPROFILEREQUEST_DBSECRETENTRY._serialized_start=4942
  _DSCREATERECIPEPROFILEREQUEST_DBSECRETENTRY._serialized_end=4989
  _DSCREATERECIPEPROFILERESPONSE._serialized_start=6146
  _DSCREATERECIPEPROFILERESPONSE._serialized_end=6254
  _DATASOURCERESPONSE._serialized_start=6256
  _DATASOURCERESPONSE._serialized_end=6276
  _DATASETRESPONSE._serialized_start=6278
  _DATASETRESPONSE._serialized_end=6295
  _DSCREATEDATASETPROFILEREQUEST._serialized_start=6298
  _DSCREATEDATASETPROFILEREQUEST._serialized_end=7289
  _DSCREATEDATASETPROFILEREQUEST_STORAGESECRETENTRY._serialized_start=4888
  _DSCREATEDATASETPROFILEREQUEST_STORAGESECRETENTRY._serialized_end=4940
  _DSCREATEDATASETPROFILEREQUEST_DBSECRETENTRY._serialized_start=4942
  _DSCREATEDATASETPROFILEREQUEST_DBSECRETENTRY._serialized_end=4989
  _DSCREATEDATASETPROFILERESPONSE._serialized_start=7292
  _DSCREATEDATASETPROFILERESPONSE._serialized_end=7420
  _DSCREATEMODELPROFILEREQUEST._serialized_start=7423
  _DSCREATEMODELPROFILEREQUEST._serialized_end=8525
  _DSCREATEMODELPROFILEREQUEST_SECRETENTRY._serialized_start=1036
  _DSCREATEMODELPROFILEREQUEST_SECRETENTRY._serialized_end=1081
  _DSCREATEMODELPROFILEREQUEST_DBSECRETENTRY._serialized_start=4942
  _DSCREATEMODELPROFILEREQUEST_DBSECRETENTRY._serialized_end=4989
  _DSCREATEMODELPROFILERESPONSE._serialized_start=8527
  _DSCREATEMODELPROFILERESPONSE._serialized_end=8570
  _DSMERGEFORECASTFILEREQUEST._serialized_start=8573
  _DSMERGEFORECASTFILEREQUEST._serialized_end=9691
  _DSMERGEFORECASTFILEREQUEST_SECRETENTRY._serialized_start=1036
  _DSMERGEFORECASTFILEREQUEST_SECRETENTRY._serialized_end=1081
  _DSMERGEFORECASTFILEREQUEST_DBSECRETENTRY._serialized_start=4942
  _DSMERGEFORECASTFILEREQUEST_DBSECRETENTRY._serialized_end=4989
  _DSMERGEFORECASTFILERESPONSE._serialized_start=9693
  _DSMERGEFORECASTFILERESPONSE._serialized_end=9735
  _DSCREATESTUDYPROFILEREQUEST._serialized_start=9738
  _DSCREATESTUDYPROFILEREQUEST._serialized_end=10841
  _DSCREATESTUDYPROFILEREQUEST_SECRETENTRY._serialized_start=1036
  _DSCREATESTUDYPROFILEREQUEST_SECRETENTRY._serialized_end=1081
  _DSCREATESTUDYPROFILEREQUEST_DBSECRETENTRY._serialized_start=4942
  _DSCREATESTUDYPROFILEREQUEST_DBSECRETENTRY._serialized_end=4989
  _DSCREATESTUDYPROFILERESPONSE._serialized_start=10843
  _DSCREATESTUDYPROFILERESPONSE._serialized_end=10886
  _RUNTESTSUITEREQUEST._serialized_start=10889
  _RUNTESTSUITEREQUEST._serialized_end=13145
  _RUNTESTSUITEREQUEST_SECRETENTRY._serialized_start=1036
  _RUNTESTSUITEREQUEST_SECRETENTRY._serialized_end=1081
  _RUNTESTSUITEREQUEST_DBSECRETENTRY._serialized_start=4942
  _RUNTESTSUITEREQUEST_DBSECRETENTRY._serialized_end=4989
  _RUNTESTSUITERESPONSE._serialized_start=13147
  _RUNTESTSUITERESPONSE._serialized_end=13259
  _DSGENERATEDATASETREQUEST._serialized_start=13262
  _DSGENERATEDATASETREQUEST._serialized_end=14129
  _DSGENERATEDATASETREQUEST_SECRETENTRY._serialized_start=1036
  _DSGENERATEDATASETREQUEST_SECRETENTRY._serialized_end=1081
  _DSGENERATEDATASETREQUEST_DBSECRETENTRY._serialized_start=4942
  _DSGENERATEDATASETREQUEST_DBSECRETENTRY._serialized_end=4989
  _DSGENERATEDATASETRESPONSE._serialized_start=14131
  _DSGENERATEDATASETRESPONSE._serialized_end=14171
  _DSSPLITDATASETREQUEST._serialized_start=14174
  _DSSPLITDATASETREQUEST._serialized_end=15368
  _DSSPLITDATASETREQUEST_SECRETENTRY._serialized_start=1036
  _DSSPLITDATASETREQUEST_SECRETENTRY._serialized_end=1081
  _DSSPLITDATASETREQUEST_DBSECRETENTRY._serialized_start=4942
  _DSSPLITDATASETREQUEST_DBSECRETENTRY._serialized_end=4989
  _DSSPLITDATASETRESPONSE._serialized_start=15371
  _DSSPLITDATASETRESPONSE._serialized_end=15539
  _DSSPLITDATASETTORUNGSREQUEST._serialized_start=15542
  _DSSPLITDATASETTORUNGSREQUEST._serialized_end=16254
  _DSSPLITDATASETTORUNGSREQUEST_SECRETENTRY._serialized_start=1036
  _DSSPLITDATASETTORUNGSREQUEST_SECRETENTRY._serialized_end=1081
  _DSSPLITDATASETTORUNGSRESPONSE._serialized_start=16256
  _DSSPLITDATASETTORUNGSRESPONSE._serialized_end=16287
  _DSTRANSFORMREQUEST._serialized_start=16290
  _DSTRANSFORMREQUEST._serialized_end=17222
  _DSTRANSFORMREQUEST_SECRETENTRY._serialized_start=1036
  _DSTRANSFORMREQUEST_SECRETENTRY._serialized_end=1081
  _DSTRANSFORMRESPONSE._serialized_start=17224
  _DSTRANSFORMRESPONSE._serialized_end=17315
  _DSCREATECOLUMNPROFILEREQUEST._serialized_start=17318
  _DSCREATECOLUMNPROFILEREQUEST._serialized_end=18303
  _DSCREATECOLUMNPROFILEREQUEST_SECRETENTRY._serialized_start=1036
  _DSCREATECOLUMNPROFILEREQUEST_SECRETENTRY._serialized_end=1081
  _DSCREATECOLUMNPROFILEREQUEST_DBSECRETENTRY._serialized_start=4942
  _DSCREATECOLUMNPROFILEREQUEST_DBSECRETENTRY._serialized_end=4989
  _DSCREATECOLUMNPROFILERESPONSE._serialized_start=18305
  _DSCREATECOLUMNPROFILERESPONSE._serialized_end=18420
  _GROUPBYDATASETREQUEST._serialized_start=18423
  _GROUPBYDATASETREQUEST._serialized_end=19347
  _GROUPBYDATASETREQUEST_SECRETENTRY._serialized_start=1036
  _GROUPBYDATASETREQUEST_SECRETENTRY._serialized_end=1081
  _GROUPBYDATASETREQUEST_DBSECRETENTRY._serialized_start=4942
  _GROUPBYDATASETREQUEST_DBSECRETENTRY._serialized_end=4989
  _GROUPBYDATASETRESPONSE._serialized_start=19349
  _GROUPBYDATASETRESPONSE._serialized_end=19386
  _DSINFERSCHEMAREQUEST._serialized_start=19389
  _DSINFERSCHEMAREQUEST._serialized_end=19901
  _DSINFERSCHEMAREQUEST_SECRETENTRY._serialized_start=1036
  _DSINFERSCHEMAREQUEST_SECRETENTRY._serialized_end=1081
  _DSINFERSCHEMARESPONSE._serialized_start=19903
  _DSINFERSCHEMARESPONSE._serialized_end=20009
  _DSGETTABLEVIEWREQUEST._serialized_start=20012
  _DSGETTABLEVIEWREQUEST._serialized_end=20773
  _DSGETTABLEVIEWREQUEST_SECRETENTRY._serialized_start=1036
  _DSGETTABLEVIEWREQUEST_SECRETENTRY._serialized_end=1081
  _DSGETTABLEVIEWREQUEST_DBSECRETENTRY._serialized_start=4942
  _DSGETTABLEVIEWREQUEST_DBSECRETENTRY._serialized_end=4989
  _DSGETTABLEVIEWRESPONSE._serialized_start=20775
  _DSGETTABLEVIEWRESPONSE._serialized_end=20879
  _CREATEMODELREPORTREQUEST._serialized_start=20882
  _CREATEMODELREPORTREQUEST._serialized_end=21828
  _CREATEMODELREPORTREQUEST_SECRETENTRY._serialized_start=1036
  _CREATEMODELREPORTREQUEST_SECRETENTRY._serialized_end=1081
  _CREATEFORECASTREPORTREQUEST._serialized_start=21831
  _CREATEFORECASTREPORTREQUEST._serialized_end=23033
  _CREATEFORECASTREPORTREQUEST_SECRETENTRY._serialized_start=1036
  _CREATEFORECASTREPORTREQUEST_SECRETENTRY._serialized_end=1081
  _CREATEFORECASTREPORTREQUEST_DBSECRETENTRY._serialized_start=4942
  _CREATEFORECASTREPORTREQUEST_DBSECRETENTRY._serialized_end=4989
  _CREATESUMMARYREPORTREQUEST._serialized_start=23036
  _CREATESUMMARYREPORTREQUEST._serialized_end=23891
  _CREATESUMMARYREPORTREQUEST_SECRETENTRY._serialized_start=1036
  _CREATESUMMARYREPORTREQUEST_SECRETENTRY._serialized_end=1081
  _CREATESUMMARYREPORTREQUEST_DBSECRETENTRY._serialized_start=4942
  _CREATESUMMARYREPORTREQUEST_DBSECRETENTRY._serialized_end=4989
  _CREATEREPORTRESPONSE._serialized_start=23893
  _CREATEREPORTRESPONSE._serialized_end=23928
  _CREATEDATASETREPORTREQUEST._serialized_start=23931
  _CREATEDATASETREPORTREQUEST._serialized_end=24967
  _CREATEDATASETREPORTREQUEST_SECRETENTRY._serialized_start=1036
  _CREATEDATASETREPORTREQUEST_SECRETENTRY._serialized_end=1081
  _CREATEDATASETREPORTREQUEST_DBSECRETENTRY._serialized_start=4942
  _CREATEDATASETREPORTREQUEST_DBSECRETENTRY._serialized_end=4989
  _CREATESTUDYREPORTREQUEST._serialized_start=24970
  _CREATESTUDYREPORTREQUEST._serialized_end=26150
  _CREATESTUDYREPORTREQUEST_SECRETENTRY._serialized_start=1036
  _CREATESTUDYREPORTREQUEST_SECRETENTRY._serialized_end=1081
  _CREATESTUDYREPORTREQUEST_DBSECRETENTRY._serialized_start=4942
  _CREATESTUDYREPORTREQUEST_DBSECRETENTRY._serialized_end=4989
  _ASKMODELREQUEST._serialized_start=26153
  _ASKMODELREQUEST._serialized_end=26733
  _GETTIMESERIESDATASETKEYSREQUEST._serialized_start=26736
  _GETTIMESERIESDATASETKEYSREQUEST._serialized_end=27190
  _GETTIMESERIESDATASETKEYSRESPONSE._serialized_start=27192
  _GETTIMESERIESDATASETKEYSRESPONSE._serialized_end=27240
  _ASKFORECASTMODELREQUEST._serialized_start=27243
  _ASKFORECASTMODELREQUEST._serialized_end=27791
  _ASKFORECASTMODELRESPONSE._serialized_start=27793
  _ASKFORECASTMODELRESPONSE._serialized_end=27899
  _ASKENSEMBLEREQUEST._serialized_start=27902
  _ASKENSEMBLEREQUEST._serialized_end=28512
  _ASKENSEMBLERESPONSE._serialized_start=28514
  _ASKENSEMBLERESPONSE._serialized_end=28615
  _ASKBASELINEREQUEST._serialized_start=28618
  _ASKBASELINEREQUEST._serialized_end=29178
  _ASKBASELINERESPONSE._serialized_start=29180
  _ASKBASELINERESPONSE._serialized_end=29281
  _ASKALLMODELSFORTASKREQUEST._serialized_start=29284
  _ASKALLMODELSFORTASKREQUEST._serialized_end=29851
  _ASKALLMODELSFORTASKRESPONSE._serialized_start=29853
  _ASKALLMODELSFORTASKRESPONSE._serialized_end=29962
  _TELLMODELREQUEST._serialized_start=29965
  _TELLMODELREQUEST._serialized_end=30500
  _TELLMODELRESPONSE._serialized_start=30502
  _TELLMODELRESPONSE._serialized_end=30537
  _DSSHUTDOWNREQUEST._serialized_start=30539
  _DSSHUTDOWNREQUEST._serialized_end=30558
  _DSSHUTDOWNRESPONSE._serialized_start=30560
  _DSSHUTDOWNRESPONSE._serialized_end=30580
  _DSTESTCONNECTIONREQUEST._serialized_start=30583
  _DSTESTCONNECTIONREQUEST._serialized_end=30929
  _DSTESTCONNECTIONREQUEST_SECRETENTRY._serialized_start=1036
  _DSTESTCONNECTIONREQUEST_SECRETENTRY._serialized_end=1081
  _DSTESTCONNECTIONRESPONSE._serialized_start=30931
  _DSTESTCONNECTIONRESPONSE._serialized_end=30986
  _DSSTUDYENDEDREQUEST._serialized_start=30989
  _DSSTUDYENDEDREQUEST._serialized_end=31748
  _DSSTUDYENDEDREQUEST_SECRETENTRY._serialized_start=1036
  _DSSTUDYENDEDREQUEST_SECRETENTRY._serialized_end=1081
  _DSSTUDYENDEDRESPONSE._serialized_start=31750
  _DSSTUDYENDEDRESPONSE._serialized_end=31772
  _SAVEOPTIMIZERDBREQUEST._serialized_start=31775
  _SAVEOPTIMIZERDBREQUEST._serialized_end=32540
  _SAVEOPTIMIZERDBREQUEST_SECRETENTRY._serialized_start=1036
  _SAVEOPTIMIZERDBREQUEST_SECRETENTRY._serialized_end=1081
  _SAVEOPTIMIZERDBRESPONSE._serialized_start=32542
  _SAVEOPTIMIZERDBRESPONSE._serialized_end=32567
  _DSGETDATABASESREQUEST._serialized_start=32570
  _DSGETDATABASESREQUEST._serialized_end=32826
  _DSGETDATABASESREQUEST_SECRETENTRY._serialized_start=1036
  _DSGETDATABASESREQUEST_SECRETENTRY._serialized_end=1081
  _DSGETDATABASESRESPONSE._serialized_start=32828
  _DSGETDATABASESRESPONSE._serialized_end=32871
  _DSGETTABLESREQUEST._serialized_start=32874
  _DSGETTABLESREQUEST._serialized_end=33146
  _DSGETTABLESREQUEST_SECRETENTRY._serialized_start=1036
  _DSGETTABLESREQUEST_SECRETENTRY._serialized_end=1081
  _DSGETTABLESRESPONSE._serialized_start=33148
  _DSGETTABLESRESPONSE._serialized_end=33185
  _DSEXECUTESQLREQUEST._serialized_start=33188
  _DSEXECUTESQLREQUEST._serialized_end=33475
  _DSEXECUTESQLREQUEST_SECRETENTRY._serialized_start=1036
  _DSEXECUTESQLREQUEST_SECRETENTRY._serialized_end=1081
  _DSEXECUTESQLRESPONSE._serialized_start=33477
  _DSEXECUTESQLRESPONSE._serialized_end=33579
  _DSSNAPSHOTREQUEST._serialized_start=33582
  _DSSNAPSHOTREQUEST._serialized_end=34535
  _DSSNAPSHOTREQUEST_DBSECRETENTRY._serialized_start=34434
  _DSSNAPSHOTREQUEST_DBSECRETENTRY._serialized_end=34481
  _DSSNAPSHOTREQUEST_STORAGESECRETENTRY._serialized_start=34483
  _DSSNAPSHOTREQUEST_STORAGESECRETENTRY._serialized_end=34535
  _DSSNAPSHOTRESPONSE._serialized_start=34537
  _DSSNAPSHOTRESPONSE._serialized_end=34557
  _ASKMODELRESPONSE._serialized_start=34559
  _ASKMODELRESPONSE._serialized_end=34657
  _GENTRAININGDATAREQUEST._serialized_start=34660
  _GENTRAININGDATAREQUEST._serialized_end=35705
  _GENTRAININGDATAREQUEST_STORAGESECRETENTRY._serialized_start=4888
  _GENTRAININGDATAREQUEST_STORAGESECRETENTRY._serialized_end=4940
  _GENTRAININGDATAREQUEST_DBSECRETENTRY._serialized_start=4942
  _GENTRAININGDATAREQUEST_DBSECRETENTRY._serialized_end=4989
  _GENTRAININGDATARESPONSE._serialized_start=35707
  _GENTRAININGDATARESPONSE._serialized_end=35746
  _SYNCONLINESTOREREQUEST._serialized_start=35749
  _SYNCONLINESTOREREQUEST._serialized_end=36621
  _SYNCONLINESTOREREQUEST_STORAGESECRETENTRY._serialized_start=4888
  _SYNCONLINESTOREREQUEST_STORAGESECRETENTRY._serialized_end=4940
  _SYNCONLINESTOREREQUEST_DBSECRETENTRY._serialized_start=4942
  _SYNCONLINESTOREREQUEST_DBSECRETENTRY._serialized_end=4989
  _SYNCONLINESTORERESPONSE._serialized_start=36623
  _SYNCONLINESTORERESPONSE._serialized_end=36648
  _GENONLINESTOREDATASETREQUEST._serialized_start=36651
  _GENONLINESTOREDATASETREQUEST._serialized_end=37541
  _GENONLINESTOREDATASETREQUEST_STORAGESECRETENTRY._serialized_start=4888
  _GENONLINESTOREDATASETREQUEST_STORAGESECRETENTRY._serialized_end=4940
  _GENONLINESTOREDATASETREQUEST_DBSECRETENTRY._serialized_start=4942
  _GENONLINESTOREDATASETREQUEST_DBSECRETENTRY._serialized_end=4989
  _GENONLINESTOREDATASETRESPONSE._serialized_start=37543
  _GENONLINESTOREDATASETRESPONSE._serialized_end=37660
  _BATCHPREDICTREQUEST._serialized_start=37663
  _BATCHPREDICTREQUEST._serialized_end=38700
  _BATCHPREDICTREQUEST_STORAGESECRETENTRY._serialized_start=4888
  _BATCHPREDICTREQUEST_STORAGESECRETENTRY._serialized_end=4940
  _BATCHPREDICTREQUEST_DBSECRETENTRY._serialized_start=4942
  _BATCHPREDICTREQUEST_DBSECRETENTRY._serialized_end=4989
  _BATCHPREDICTRESPONSE._serialized_start=38702
  _BATCHPREDICTRESPONSE._serialized_end=38738
  _SAVEDATASETREQUEST._serialized_start=38741
  _SAVEDATASETREQUEST._serialized_end=39863
  _SAVEDATASETREQUEST_STORAGESECRETENTRY._serialized_start=4888
  _SAVEDATASETREQUEST_STORAGESECRETENTRY._serialized_end=4940
  _SAVEDATASETREQUEST_DBSECRETENTRY._serialized_start=4942
  _SAVEDATASETREQUEST_DBSECRETENTRY._serialized_end=4989
  _SAVEMODELREQUEST._serialized_start=39866
  _SAVEMODELREQUEST._serialized_end=41140
  _SAVEMODELREQUEST_STORAGESECRETENTRY._serialized_start=4888
  _SAVEMODELREQUEST_STORAGESECRETENTRY._serialized_end=4940
  _SAVEMODELREQUEST_DBSECRETENTRY._serialized_start=4942
  _SAVEMODELREQUEST_DBSECRETENTRY._serialized_end=4989
  _SAVEPREDICTIONREQUEST._serialized_start=41143
  _SAVEPREDICTIONREQUEST._serialized_end=42208
  _SAVEPREDICTIONREQUEST_STORAGESECRETENTRY._serialized_start=4888
  _SAVEPREDICTIONREQUEST_STORAGESECRETENTRY._serialized_end=4940
  _SAVEPREDICTIONREQUEST_DBSECRETENTRY._serialized_start=4942
  _SAVEPREDICTIONREQUEST_DBSECRETENTRY._serialized_end=4989
  _CREATEMETRICSSTOREREQUEST._serialized_start=42210
  _CREATEMETRICSSTOREREQUEST._serialized_end=42253
  _CREATEMETRICSSTORERESPONSE._serialized_start=42255
  _CREATEMETRICSSTORERESPONSE._serialized_end=42283
  _SAVERESPONSE._serialized_start=42285
  _SAVERESPONSE._serialized_end=42313
  _DATASERVICE._serialized_start=42316
  _DATASERVICE._serialized_end=51011
# @@protoc_insertion_point(module_scope)
